# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/exchange/v1beta1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from pyinjective.proto.injective.exchange.v1beta1 import exchange_pb2 as injective_dot_exchange_dot_v1beta1_dot_exchange__pb2
from pyinjective.proto.injective.exchange.v1beta1 import genesis_pb2 as injective_dot_exchange_dot_v1beta1_dot_genesis__pb2
from pyinjective.proto.injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&injective/exchange/v1beta1/query.proto\x12\x1ainjective.exchange.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a)injective/exchange/v1beta1/exchange.proto\x1a(injective/exchange/v1beta1/genesis.proto\x1a%injective/oracle/v1beta1/oracle.proto\x1a\x14gogoproto/gogo.proto\"O\n\nSubaccount\x12\x16\n\x06trader\x18\x01 \x01(\tR\x06trader\x12)\n\x10subaccount_nonce\x18\x02 \x01(\rR\x0fsubaccountNonce\"`\n\x1cQuerySubaccountOrdersRequest\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\"\xc1\x01\n\x1dQuerySubaccountOrdersResponse\x12N\n\nbuy_orders\x18\x01 \x03(\x0b\x32/.injective.exchange.v1beta1.SubaccountOrderDataR\tbuyOrders\x12P\n\x0bsell_orders\x18\x02 \x03(\x0b\x32/.injective.exchange.v1beta1.SubaccountOrderDataR\nsellOrders\"\xaf\x01\n%SubaccountOrderbookMetadataWithMarket\x12S\n\x08metadata\x18\x01 \x01(\x0b\x32\x37.injective.exchange.v1beta1.SubaccountOrderbookMetadataR\x08metadata\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x14\n\x05isBuy\x18\x03 \x01(\x08R\x05isBuy\"\x1c\n\x1aQueryExchangeParamsRequest\"_\n\x1bQueryExchangeParamsResponse\x12@\n\x06params\x18\x01 \x01(\x0b\x32\".injective.exchange.v1beta1.ParamsB\x04\xc8\xde\x1f\x00R\x06params\"\x93\x01\n\x1eQuerySubaccountDepositsRequest\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12L\n\nsubaccount\x18\x02 \x01(\x0b\x32&.injective.exchange.v1beta1.SubaccountB\x04\xc8\xde\x1f\x01R\nsubaccount\"\xea\x01\n\x1fQuerySubaccountDepositsResponse\x12\x65\n\x08\x64\x65posits\x18\x01 \x03(\x0b\x32I.injective.exchange.v1beta1.QuerySubaccountDepositsResponse.DepositsEntryR\x08\x64\x65posits\x1a`\n\rDepositsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x39\n\x05value\x18\x02 \x01(\x0b\x32#.injective.exchange.v1beta1.DepositR\x05value:\x02\x38\x01\"\x1e\n\x1cQueryExchangeBalancesRequest\"f\n\x1dQueryExchangeBalancesResponse\x12\x45\n\x08\x62\x61lances\x18\x01 \x03(\x0b\x32#.injective.exchange.v1beta1.BalanceB\x04\xc8\xde\x1f\x00R\x08\x62\x61lances\"7\n\x1bQueryAggregateVolumeRequest\x12\x18\n\x07\x61\x63\x63ount\x18\x01 \x01(\tR\x07\x61\x63\x63ount\"u\n\x1cQueryAggregateVolumeResponse\x12U\n\x11\x61ggregate_volumes\x18\x01 \x03(\x0b\x32(.injective.exchange.v1beta1.MarketVolumeR\x10\x61ggregateVolumes\"Y\n\x1cQueryAggregateVolumesRequest\x12\x1a\n\x08\x61\x63\x63ounts\x18\x01 \x03(\tR\x08\x61\x63\x63ounts\x12\x1d\n\nmarket_ids\x18\x02 \x03(\tR\tmarketIds\"\xf9\x01\n\x1dQueryAggregateVolumesResponse\x12t\n\x19\x61ggregate_account_volumes\x18\x01 \x03(\x0b\x32\x38.injective.exchange.v1beta1.AggregateAccountVolumeRecordR\x17\x61ggregateAccountVolumes\x12\x62\n\x18\x61ggregate_market_volumes\x18\x02 \x03(\x0b\x32(.injective.exchange.v1beta1.MarketVolumeR\x16\x61ggregateMarketVolumes\"@\n!QueryAggregateMarketVolumeRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"l\n\"QueryAggregateMarketVolumeResponse\x12\x46\n\x06volume\x18\x01 \x01(\x0b\x32(.injective.exchange.v1beta1.VolumeRecordB\x04\xc8\xde\x1f\x00R\x06volume\"0\n\x18QueryDenomDecimalRequest\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\"5\n\x19QueryDenomDecimalResponse\x12\x18\n\x07\x64\x65\x63imal\x18\x01 \x01(\x04R\x07\x64\x65\x63imal\"3\n\x19QueryDenomDecimalsRequest\x12\x16\n\x06\x64\x65noms\x18\x01 \x03(\tR\x06\x64\x65noms\"t\n\x1aQueryDenomDecimalsResponse\x12V\n\x0e\x64\x65nom_decimals\x18\x01 \x03(\x0b\x32).injective.exchange.v1beta1.DenomDecimalsB\x04\xc8\xde\x1f\x00R\rdenomDecimals\"C\n\"QueryAggregateMarketVolumesRequest\x12\x1d\n\nmarket_ids\x18\x01 \x03(\tR\tmarketIds\"i\n#QueryAggregateMarketVolumesResponse\x12\x42\n\x07volumes\x18\x01 \x03(\x0b\x32(.injective.exchange.v1beta1.MarketVolumeR\x07volumes\"Z\n\x1dQuerySubaccountDepositRequest\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x14\n\x05\x64\x65nom\x18\x02 \x01(\tR\x05\x64\x65nom\"a\n\x1eQuerySubaccountDepositResponse\x12?\n\x08\x64\x65posits\x18\x01 \x01(\x0b\x32#.injective.exchange.v1beta1.DepositR\x08\x64\x65posits\"P\n\x17QuerySpotMarketsRequest\x12\x16\n\x06status\x18\x01 \x01(\tR\x06status\x12\x1d\n\nmarket_ids\x18\x02 \x03(\tR\tmarketIds\"\\\n\x18QuerySpotMarketsResponse\x12@\n\x07markets\x18\x01 \x03(\x0b\x32&.injective.exchange.v1beta1.SpotMarketR\x07markets\"5\n\x16QuerySpotMarketRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"Y\n\x17QuerySpotMarketResponse\x12>\n\x06market\x18\x01 \x01(\x0b\x32&.injective.exchange.v1beta1.SpotMarketR\x06market\"\xd6\x02\n\x19QuerySpotOrderbookRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x14\n\x05limit\x18\x02 \x01(\x04R\x05limit\x12\x44\n\norder_side\x18\x03 \x01(\x0e\x32%.injective.exchange.v1beta1.OrderSideR\torderSide\x12_\n\x19limit_cumulative_notional\x18\x04 \x01(\tB#\xc8\xde\x1f\x01\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x17limitCumulativeNotional\x12_\n\x19limit_cumulative_quantity\x18\x05 \x01(\tB#\xc8\xde\x1f\x01\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x17limitCumulativeQuantity\"\xb8\x01\n\x1aQuerySpotOrderbookResponse\x12K\n\x10\x62uys_price_level\x18\x01 \x03(\x0b\x32!.injective.exchange.v1beta1.LevelR\x0e\x62uysPriceLevel\x12M\n\x11sells_price_level\x18\x02 \x03(\x0b\x32!.injective.exchange.v1beta1.LevelR\x0fsellsPriceLevel\"\xad\x01\n\x0e\x46ullSpotMarket\x12>\n\x06market\x18\x01 \x01(\x0b\x32&.injective.exchange.v1beta1.SpotMarketR\x06market\x12[\n\x11mid_price_and_tob\x18\x02 \x01(\x0b\x32*.injective.exchange.v1beta1.MidPriceAndTOBB\x04\xc8\xde\x1f\x01R\x0emidPriceAndTob\"\x88\x01\n\x1bQueryFullSpotMarketsRequest\x12\x16\n\x06status\x18\x01 \x01(\tR\x06status\x12\x1d\n\nmarket_ids\x18\x02 \x03(\tR\tmarketIds\x12\x32\n\x16with_mid_price_and_tob\x18\x03 \x01(\x08R\x12withMidPriceAndTob\"d\n\x1cQueryFullSpotMarketsResponse\x12\x44\n\x07markets\x18\x01 \x03(\x0b\x32*.injective.exchange.v1beta1.FullSpotMarketR\x07markets\"m\n\x1aQueryFullSpotMarketRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x32\n\x16with_mid_price_and_tob\x18\x02 \x01(\x08R\x12withMidPriceAndTob\"a\n\x1bQueryFullSpotMarketResponse\x12\x42\n\x06market\x18\x01 \x01(\x0b\x32*.injective.exchange.v1beta1.FullSpotMarketR\x06market\"\x85\x01\n\x1eQuerySpotOrdersByHashesRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\x12!\n\x0corder_hashes\x18\x03 \x03(\tR\x0borderHashes\"l\n\x1fQuerySpotOrdersByHashesResponse\x12I\n\x06orders\x18\x01 \x03(\x0b\x32\x31.injective.exchange.v1beta1.TrimmedSpotLimitOrderR\x06orders\"`\n\x1cQueryTraderSpotOrdersRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\"l\n$QueryAccountAddressSpotOrdersRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\'\n\x0f\x61\x63\x63ount_address\x18\x02 \x01(\tR\x0e\x61\x63\x63ountAddress\"\x9b\x02\n\x15TrimmedSpotLimitOrder\x12\x39\n\x05price\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05price\x12?\n\x08quantity\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x08quantity\x12?\n\x08\x66illable\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x08\x66illable\x12\x14\n\x05isBuy\x18\x04 \x01(\x08R\x05isBuy\x12\x1d\n\norder_hash\x18\x05 \x01(\tR\torderHash\x12\x10\n\x03\x63id\x18\x06 \x01(\tR\x03\x63id\"j\n\x1dQueryTraderSpotOrdersResponse\x12I\n\x06orders\x18\x01 \x03(\x0b\x32\x31.injective.exchange.v1beta1.TrimmedSpotLimitOrderR\x06orders\"r\n%QueryAccountAddressSpotOrdersResponse\x12I\n\x06orders\x18\x01 \x03(\x0b\x32\x31.injective.exchange.v1beta1.TrimmedSpotLimitOrderR\x06orders\"=\n\x1eQuerySpotMidPriceAndTOBRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"\xfb\x01\n\x1fQuerySpotMidPriceAndTOBResponse\x12@\n\tmid_price\x18\x01 \x01(\tB#\xc8\xde\x1f\x01\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x08midPrice\x12I\n\x0e\x62\x65st_buy_price\x18\x02 \x01(\tB#\xc8\xde\x1f\x01\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0c\x62\x65stBuyPrice\x12K\n\x0f\x62\x65st_sell_price\x18\x03 \x01(\tB#\xc8\xde\x1f\x01\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\rbestSellPrice\"C\n$QueryDerivativeMidPriceAndTOBRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"\x81\x02\n%QueryDerivativeMidPriceAndTOBResponse\x12@\n\tmid_price\x18\x01 \x01(\tB#\xc8\xde\x1f\x01\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x08midPrice\x12I\n\x0e\x62\x65st_buy_price\x18\x02 \x01(\tB#\xc8\xde\x1f\x01\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0c\x62\x65stBuyPrice\x12K\n\x0f\x62\x65st_sell_price\x18\x03 \x01(\tB#\xc8\xde\x1f\x01\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\rbestSellPrice\"\xb5\x01\n\x1fQueryDerivativeOrderbookRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x14\n\x05limit\x18\x02 \x01(\x04R\x05limit\x12_\n\x19limit_cumulative_notional\x18\x03 \x01(\tB#\xc8\xde\x1f\x01\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x17limitCumulativeNotional\"\xbe\x01\n QueryDerivativeOrderbookResponse\x12K\n\x10\x62uys_price_level\x18\x01 \x03(\x0b\x32!.injective.exchange.v1beta1.LevelR\x0e\x62uysPriceLevel\x12M\n\x11sells_price_level\x18\x02 \x03(\x0b\x32!.injective.exchange.v1beta1.LevelR\x0fsellsPriceLevel\"\x9c\x03\n.QueryTraderSpotOrdersToCancelUpToAmountRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\x12\x44\n\x0b\x62\x61se_amount\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\nbaseAmount\x12\x46\n\x0cquote_amount\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0bquoteAmount\x12L\n\x08strategy\x18\x05 \x01(\x0e\x32\x30.injective.exchange.v1beta1.CancellationStrategyR\x08strategy\x12L\n\x0freference_price\x18\x06 \x01(\tB#\xc8\xde\x1f\x01\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0ereferencePrice\"\xdc\x02\n4QueryTraderDerivativeOrdersToCancelUpToAmountRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\x12\x46\n\x0cquote_amount\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0bquoteAmount\x12L\n\x08strategy\x18\x04 \x01(\x0e\x32\x30.injective.exchange.v1beta1.CancellationStrategyR\x08strategy\x12L\n\x0freference_price\x18\x05 \x01(\tB#\xc8\xde\x1f\x01\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0ereferencePrice\"f\n\"QueryTraderDerivativeOrdersRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\"r\n*QueryAccountAddressDerivativeOrdersRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\'\n\x0f\x61\x63\x63ount_address\x18\x02 \x01(\tR\x0e\x61\x63\x63ountAddress\"\xe9\x02\n\x1bTrimmedDerivativeLimitOrder\x12\x39\n\x05price\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05price\x12?\n\x08quantity\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x08quantity\x12;\n\x06margin\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x06margin\x12?\n\x08\x66illable\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x08\x66illable\x12\x1f\n\x05isBuy\x18\x05 \x01(\x08\x42\t\xea\xde\x1f\x05isBuyR\x05isBuy\x12\x1d\n\norder_hash\x18\x06 \x01(\tR\torderHash\x12\x10\n\x03\x63id\x18\x07 \x01(\tR\x03\x63id\"v\n#QueryTraderDerivativeOrdersResponse\x12O\n\x06orders\x18\x01 \x03(\x0b\x32\x37.injective.exchange.v1beta1.TrimmedDerivativeLimitOrderR\x06orders\"~\n+QueryAccountAddressDerivativeOrdersResponse\x12O\n\x06orders\x18\x01 \x03(\x0b\x32\x37.injective.exchange.v1beta1.TrimmedDerivativeLimitOrderR\x06orders\"\x8b\x01\n$QueryDerivativeOrdersByHashesRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\x12!\n\x0corder_hashes\x18\x03 \x03(\tR\x0borderHashes\"x\n%QueryDerivativeOrdersByHashesResponse\x12O\n\x06orders\x18\x01 \x03(\x0b\x32\x37.injective.exchange.v1beta1.TrimmedDerivativeLimitOrderR\x06orders\"\x8a\x01\n\x1dQueryDerivativeMarketsRequest\x12\x16\n\x06status\x18\x01 \x01(\tR\x06status\x12\x1d\n\nmarket_ids\x18\x02 \x03(\tR\tmarketIds\x12\x32\n\x16with_mid_price_and_tob\x18\x03 \x01(\x08R\x12withMidPriceAndTob\"\x88\x01\n\nPriceLevel\x12\x39\n\x05price\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05price\x12?\n\x08quantity\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x08quantity\"\xbf\x01\n\x14PerpetualMarketState\x12P\n\x0bmarket_info\x18\x01 \x01(\x0b\x32/.injective.exchange.v1beta1.PerpetualMarketInfoR\nmarketInfo\x12U\n\x0c\x66unding_info\x18\x02 \x01(\x0b\x32\x32.injective.exchange.v1beta1.PerpetualMarketFundingR\x0b\x66undingInfo\"\xba\x03\n\x14\x46ullDerivativeMarket\x12\x44\n\x06market\x18\x01 \x01(\x0b\x32,.injective.exchange.v1beta1.DerivativeMarketR\x06market\x12Y\n\x0eperpetual_info\x18\x02 \x01(\x0b\x32\x30.injective.exchange.v1beta1.PerpetualMarketStateH\x00R\rperpetualInfo\x12X\n\x0c\x66utures_info\x18\x03 \x01(\x0b\x32\x33.injective.exchange.v1beta1.ExpiryFuturesMarketInfoH\x00R\x0b\x66uturesInfo\x12\x42\n\nmark_price\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\tmarkPrice\x12[\n\x11mid_price_and_tob\x18\x05 \x01(\x0b\x32*.injective.exchange.v1beta1.MidPriceAndTOBB\x04\xc8\xde\x1f\x01R\x0emidPriceAndTobB\x06\n\x04info\"l\n\x1eQueryDerivativeMarketsResponse\x12J\n\x07markets\x18\x01 \x03(\x0b\x32\x30.injective.exchange.v1beta1.FullDerivativeMarketR\x07markets\";\n\x1cQueryDerivativeMarketRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"i\n\x1dQueryDerivativeMarketResponse\x12H\n\x06market\x18\x01 \x01(\x0b\x32\x30.injective.exchange.v1beta1.FullDerivativeMarketR\x06market\"B\n#QueryDerivativeMarketAddressRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"e\n$QueryDerivativeMarketAddressResponse\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12#\n\rsubaccount_id\x18\x02 \x01(\tR\x0csubaccountId\"G\n QuerySubaccountTradeNonceRequest\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\"F\n\x1fQuerySubaccountPositionsRequest\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\"j\n&QuerySubaccountPositionInMarketRequest\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\"s\n/QuerySubaccountEffectivePositionInMarketRequest\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\"J\n#QuerySubaccountOrderMetadataRequest\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\"n\n QuerySubaccountPositionsResponse\x12J\n\x05state\x18\x01 \x03(\x0b\x32..injective.exchange.v1beta1.DerivativePositionB\x04\xc8\xde\x1f\x00R\x05state\"k\n\'QuerySubaccountPositionInMarketResponse\x12@\n\x05state\x18\x01 \x01(\x0b\x32$.injective.exchange.v1beta1.PositionB\x04\xc8\xde\x1f\x01R\x05state\"\x83\x02\n\x11\x45\x66\x66\x65\x63tivePosition\x12\x17\n\x07is_long\x18\x01 \x01(\x08R\x06isLong\x12?\n\x08quantity\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x08quantity\x12\x44\n\x0b\x65ntry_price\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\nentryPrice\x12N\n\x10\x65\x66\x66\x65\x63tive_margin\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0f\x65\x66\x66\x65\x63tiveMargin\"}\n0QuerySubaccountEffectivePositionInMarketResponse\x12I\n\x05state\x18\x01 \x01(\x0b\x32-.injective.exchange.v1beta1.EffectivePositionB\x04\xc8\xde\x1f\x01R\x05state\">\n\x1fQueryPerpetualMarketInfoRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"m\n QueryPerpetualMarketInfoResponse\x12I\n\x04info\x18\x01 \x01(\x0b\x32/.injective.exchange.v1beta1.PerpetualMarketInfoB\x04\xc8\xde\x1f\x00R\x04info\"B\n#QueryExpiryFuturesMarketInfoRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"u\n$QueryExpiryFuturesMarketInfoResponse\x12M\n\x04info\x18\x01 \x01(\x0b\x32\x33.injective.exchange.v1beta1.ExpiryFuturesMarketInfoB\x04\xc8\xde\x1f\x00R\x04info\"A\n\"QueryPerpetualMarketFundingRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"u\n#QueryPerpetualMarketFundingResponse\x12N\n\x05state\x18\x01 \x01(\x0b\x32\x32.injective.exchange.v1beta1.PerpetualMarketFundingB\x04\xc8\xde\x1f\x00R\x05state\"\x8b\x01\n$QuerySubaccountOrderMetadataResponse\x12\x63\n\x08metadata\x18\x01 \x03(\x0b\x32\x41.injective.exchange.v1beta1.SubaccountOrderbookMetadataWithMarketB\x04\xc8\xde\x1f\x00R\x08metadata\"9\n!QuerySubaccountTradeNonceResponse\x12\x14\n\x05nonce\x18\x01 \x01(\rR\x05nonce\"\x19\n\x17QueryModuleStateRequest\"Z\n\x18QueryModuleStateResponse\x12>\n\x05state\x18\x01 \x01(\x0b\x32(.injective.exchange.v1beta1.GenesisStateR\x05state\"\x17\n\x15QueryPositionsRequest\"d\n\x16QueryPositionsResponse\x12J\n\x05state\x18\x01 \x03(\x0b\x32..injective.exchange.v1beta1.DerivativePositionB\x04\xc8\xde\x1f\x00R\x05state\"q\n\x1dQueryTradeRewardPointsRequest\x12\x1a\n\x08\x61\x63\x63ounts\x18\x01 \x03(\tR\x08\x61\x63\x63ounts\x12\x34\n\x16pending_pool_timestamp\x18\x02 \x01(\x03R\x14pendingPoolTimestamp\"\x84\x01\n\x1eQueryTradeRewardPointsResponse\x12\x62\n\x1b\x61\x63\x63ount_trade_reward_points\x18\x01 \x03(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x18\x61\x63\x63ountTradeRewardPoints\"!\n\x1fQueryTradeRewardCampaignRequest\"\xfe\x04\n QueryTradeRewardCampaignResponse\x12v\n\x1ctrading_reward_campaign_info\x18\x01 \x01(\x0b\x32\x35.injective.exchange.v1beta1.TradingRewardCampaignInfoR\x19tradingRewardCampaignInfo\x12\x80\x01\n%trading_reward_pool_campaign_schedule\x18\x02 \x03(\x0b\x32..injective.exchange.v1beta1.CampaignRewardPoolR!tradingRewardPoolCampaignSchedule\x12^\n\x19total_trade_reward_points\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x16totalTradeRewardPoints\x12\x8f\x01\n-pending_trading_reward_pool_campaign_schedule\x18\x04 \x03(\x0b\x32..injective.exchange.v1beta1.CampaignRewardPoolR(pendingTradingRewardPoolCampaignSchedule\x12m\n!pending_total_trade_reward_points\x18\x05 \x03(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x1dpendingTotalTradeRewardPoints\";\n\x1fQueryIsOptedOutOfRewardsRequest\x12\x18\n\x07\x61\x63\x63ount\x18\x01 \x01(\tR\x07\x61\x63\x63ount\"D\n QueryIsOptedOutOfRewardsResponse\x12 \n\x0cis_opted_out\x18\x01 \x01(\x08R\nisOptedOut\"\'\n%QueryOptedOutOfRewardsAccountsRequest\"D\n&QueryOptedOutOfRewardsAccountsResponse\x12\x1a\n\x08\x61\x63\x63ounts\x18\x01 \x03(\tR\x08\x61\x63\x63ounts\">\n\"QueryFeeDiscountAccountInfoRequest\x12\x18\n\x07\x61\x63\x63ount\x18\x01 \x01(\tR\x07\x61\x63\x63ount\"\xe9\x01\n#QueryFeeDiscountAccountInfoResponse\x12\x1d\n\ntier_level\x18\x01 \x01(\x04R\ttierLevel\x12R\n\x0c\x61\x63\x63ount_info\x18\x02 \x01(\x0b\x32/.injective.exchange.v1beta1.FeeDiscountTierInfoR\x0b\x61\x63\x63ountInfo\x12O\n\x0b\x61\x63\x63ount_ttl\x18\x03 \x01(\x0b\x32..injective.exchange.v1beta1.FeeDiscountTierTTLR\naccountTtl\"!\n\x1fQueryFeeDiscountScheduleRequest\"\x87\x01\n QueryFeeDiscountScheduleResponse\x12\x63\n\x15\x66\x65\x65_discount_schedule\x18\x01 \x01(\x0b\x32/.injective.exchange.v1beta1.FeeDiscountScheduleR\x13\x66\x65\x65\x44iscountSchedule\"@\n\x1dQueryBalanceMismatchesRequest\x12\x1f\n\x0b\x64ust_factor\x18\x01 \x01(\x03R\ndustFactor\"\xa2\x03\n\x0f\x42\x61lanceMismatch\x12\"\n\x0csubaccountId\x18\x01 \x01(\tR\x0csubaccountId\x12\x14\n\x05\x64\x65nom\x18\x02 \x01(\tR\x05\x64\x65nom\x12\x41\n\tavailable\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\tavailable\x12\x39\n\x05total\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05total\x12\x46\n\x0c\x62\x61lance_hold\x18\x05 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0b\x62\x61lanceHold\x12J\n\x0e\x65xpected_total\x18\x06 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\rexpectedTotal\x12\x43\n\ndifference\x18\x07 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\ndifference\"|\n\x1eQueryBalanceMismatchesResponse\x12Z\n\x12\x62\x61lance_mismatches\x18\x01 \x03(\x0b\x32+.injective.exchange.v1beta1.BalanceMismatchR\x11\x62\x61lanceMismatches\"%\n#QueryBalanceWithBalanceHoldsRequest\"\x97\x02\n\x15\x42\x61lanceWithMarginHold\x12\"\n\x0csubaccountId\x18\x01 \x01(\tR\x0csubaccountId\x12\x14\n\x05\x64\x65nom\x18\x02 \x01(\tR\x05\x64\x65nom\x12\x41\n\tavailable\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\tavailable\x12\x39\n\x05total\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05total\x12\x46\n\x0c\x62\x61lance_hold\x18\x05 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0b\x62\x61lanceHold\"\x96\x01\n$QueryBalanceWithBalanceHoldsResponse\x12n\n\x1a\x62\x61lance_with_balance_holds\x18\x01 \x03(\x0b\x32\x31.injective.exchange.v1beta1.BalanceWithMarginHoldR\x17\x62\x61lanceWithBalanceHolds\"\'\n%QueryFeeDiscountTierStatisticsRequest\"9\n\rTierStatistic\x12\x12\n\x04tier\x18\x01 \x01(\x04R\x04tier\x12\x14\n\x05\x63ount\x18\x02 \x01(\x04R\x05\x63ount\"s\n&QueryFeeDiscountTierStatisticsResponse\x12I\n\nstatistics\x18\x01 \x03(\x0b\x32).injective.exchange.v1beta1.TierStatisticR\nstatistics\"\x17\n\x15MitoVaultInfosRequest\"\xc4\x01\n\x16MitoVaultInfosResponse\x12)\n\x10master_addresses\x18\x01 \x03(\tR\x0fmasterAddresses\x12\x31\n\x14\x64\x65rivative_addresses\x18\x02 \x03(\tR\x13\x64\x65rivativeAddresses\x12%\n\x0espot_addresses\x18\x03 \x03(\tR\rspotAddresses\x12%\n\x0e\x63w20_addresses\x18\x04 \x03(\tR\rcw20Addresses\"D\n\x1dQueryMarketIDFromVaultRequest\x12#\n\rvault_address\x18\x01 \x01(\tR\x0cvaultAddress\"=\n\x1eQueryMarketIDFromVaultResponse\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"A\n\"QueryHistoricalTradeRecordsRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"t\n#QueryHistoricalTradeRecordsResponse\x12M\n\rtrade_records\x18\x01 \x03(\x0b\x32(.injective.exchange.v1beta1.TradeRecordsR\x0ctradeRecords\"\xb7\x01\n\x13TradeHistoryOptions\x12,\n\x12trade_grouping_sec\x18\x01 \x01(\x04R\x10tradeGroupingSec\x12\x17\n\x07max_age\x18\x02 \x01(\x04R\x06maxAge\x12.\n\x13include_raw_history\x18\x04 \x01(\x08R\x11includeRawHistory\x12)\n\x10include_metadata\x18\x05 \x01(\x08R\x0fincludeMetadata\"\xa0\x01\n\x1cQueryMarketVolatilityRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x63\n\x15trade_history_options\x18\x02 \x01(\x0b\x32/.injective.exchange.v1beta1.TradeHistoryOptionsR\x13tradeHistoryOptions\"\x83\x02\n\x1dQueryMarketVolatilityResponse\x12?\n\nvolatility\x18\x01 \x01(\tB\x1f\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\nvolatility\x12W\n\x10history_metadata\x18\x02 \x01(\x0b\x32,.injective.oracle.v1beta1.MetadataStatisticsR\x0fhistoryMetadata\x12H\n\x0braw_history\x18\x03 \x03(\x0b\x32\'.injective.exchange.v1beta1.TradeRecordR\nrawHistory\"3\n\x19QueryBinaryMarketsRequest\x12\x16\n\x06status\x18\x01 \x01(\tR\x06status\"g\n\x1aQueryBinaryMarketsResponse\x12I\n\x07markets\x18\x01 \x03(\x0b\x32/.injective.exchange.v1beta1.BinaryOptionsMarketR\x07markets\"q\n-QueryTraderDerivativeConditionalOrdersRequest\x12#\n\rsubaccount_id\x18\x01 \x01(\tR\x0csubaccountId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\"\x9e\x03\n!TrimmedDerivativeConditionalOrder\x12\x39\n\x05price\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05price\x12?\n\x08quantity\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x08quantity\x12;\n\x06margin\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x06margin\x12G\n\x0ctriggerPrice\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0ctriggerPrice\x12\x1f\n\x05isBuy\x18\x05 \x01(\x08\x42\t\xea\xde\x1f\x05isBuyR\x05isBuy\x12%\n\x07isLimit\x18\x06 \x01(\x08\x42\x0b\xea\xde\x1f\x07isLimitR\x07isLimit\x12\x1d\n\norder_hash\x18\x07 \x01(\tR\torderHash\x12\x10\n\x03\x63id\x18\x08 \x01(\tR\x03\x63id\"\x87\x01\n.QueryTraderDerivativeConditionalOrdersResponse\x12U\n\x06orders\x18\x01 \x03(\x0b\x32=.injective.exchange.v1beta1.TrimmedDerivativeConditionalOrderR\x06orders\"<\n\x1dQueryFullSpotOrderbookRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"\xa6\x01\n\x1eQueryFullSpotOrderbookResponse\x12\x41\n\x04\x42ids\x18\x01 \x03(\x0b\x32-.injective.exchange.v1beta1.TrimmedLimitOrderR\x04\x42ids\x12\x41\n\x04\x41sks\x18\x02 \x03(\x0b\x32-.injective.exchange.v1beta1.TrimmedLimitOrderR\x04\x41sks\"B\n#QueryFullDerivativeOrderbookRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"\xac\x01\n$QueryFullDerivativeOrderbookResponse\x12\x41\n\x04\x42ids\x18\x01 \x03(\x0b\x32-.injective.exchange.v1beta1.TrimmedLimitOrderR\x04\x42ids\x12\x41\n\x04\x41sks\x18\x02 \x03(\x0b\x32-.injective.exchange.v1beta1.TrimmedLimitOrderR\x04\x41sks\"\xd3\x01\n\x11TrimmedLimitOrder\x12\x39\n\x05price\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05price\x12?\n\x08quantity\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x08quantity\x12\x1d\n\norder_hash\x18\x03 \x01(\tR\torderHash\x12#\n\rsubaccount_id\x18\x04 \x01(\tR\x0csubaccountId\"M\n.QueryMarketAtomicExecutionFeeMultiplierRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"v\n/QueryMarketAtomicExecutionFeeMultiplierResponse\x12\x43\n\nmultiplier\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\nmultiplier\"8\n\x1cQueryActiveStakeGrantRequest\x12\x18\n\x07grantee\x18\x01 \x01(\tR\x07grantee\"\xb3\x01\n\x1dQueryActiveStakeGrantResponse\x12=\n\x05grant\x18\x01 \x01(\x0b\x32\'.injective.exchange.v1beta1.ActiveGrantR\x05grant\x12S\n\x0f\x65\x66\x66\x65\x63tive_grant\x18\x02 \x01(\x0b\x32*.injective.exchange.v1beta1.EffectiveGrantR\x0e\x65\x66\x66\x65\x63tiveGrant\"T\n\x1eQueryGrantAuthorizationRequest\x12\x18\n\x07granter\x18\x01 \x01(\tR\x07granter\x12\x18\n\x07grantee\x18\x02 \x01(\tR\x07grantee\"X\n\x1fQueryGrantAuthorizationResponse\x12\x35\n\x06\x61mount\x18\x01 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x06\x61mount\";\n\x1fQueryGrantAuthorizationsRequest\x12\x18\n\x07granter\x18\x01 \x01(\tR\x07granter\"\xb7\x01\n QueryGrantAuthorizationsResponse\x12K\n\x12total_grant_amount\x18\x01 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x10totalGrantAmount\x12\x46\n\x06grants\x18\x02 \x03(\x0b\x32..injective.exchange.v1beta1.GrantAuthorizationR\x06grants\"8\n\x19QueryMarketBalanceRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\"a\n\x1aQueryMarketBalanceResponse\x12\x43\n\x07\x62\x61lance\x18\x01 \x01(\x0b\x32).injective.exchange.v1beta1.MarketBalanceR\x07\x62\x61lance\"\x1c\n\x1aQueryMarketBalancesRequest\"d\n\x1bQueryMarketBalancesResponse\x12\x45\n\x08\x62\x61lances\x18\x01 \x03(\x0b\x32).injective.exchange.v1beta1.MarketBalanceR\x08\x62\x61lances\"k\n\rMarketBalance\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12=\n\x07\x62\x61lance\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x07\x62\x61lance\"4\n\x1cQueryDenomMinNotionalRequest\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\"\\\n\x1dQueryDenomMinNotionalResponse\x12;\n\x06\x61mount\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x06\x61mount\"\x1f\n\x1dQueryDenomMinNotionalsRequest\"~\n\x1eQueryDenomMinNotionalsResponse\x12\\\n\x13\x64\x65nom_min_notionals\x18\x01 \x03(\x0b\x32,.injective.exchange.v1beta1.DenomMinNotionalR\x11\x64\x65nomMinNotionals*4\n\tOrderSide\x12\x14\n\x10Side_Unspecified\x10\x00\x12\x07\n\x03\x42uy\x10\x01\x12\x08\n\x04Sell\x10\x02*V\n\x14\x43\x61ncellationStrategy\x12\x14\n\x10UnspecifiedOrder\x10\x00\x12\x13\n\x0f\x46romWorstToBest\x10\x01\x12\x13\n\x0f\x46romBestToWorst\x10\x02\x32\x89o\n\x05Query\x12\xe2\x01\n\x15L3DerivativeOrderBook\x12?.injective.exchange.v1beta1.QueryFullDerivativeOrderbookRequest\x1a@.injective.exchange.v1beta1.QueryFullDerivativeOrderbookResponse\"F\x82\xd3\xe4\x93\x02@\x12>/injective/exchange/v1beta1/derivative/L3OrderBook/{market_id}\x12\xca\x01\n\x0fL3SpotOrderBook\x12\x39.injective.exchange.v1beta1.QueryFullSpotOrderbookRequest\x1a:.injective.exchange.v1beta1.QueryFullSpotOrderbookResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/injective/exchange/v1beta1/spot/L3OrderBook/{market_id}\x12\xba\x01\n\x13QueryExchangeParams\x12\x36.injective.exchange.v1beta1.QueryExchangeParamsRequest\x1a\x37.injective.exchange.v1beta1.QueryExchangeParamsResponse\"2\x82\xd3\xe4\x93\x02,\x12*/injective/exchange/v1beta1/exchangeParams\x12\xce\x01\n\x12SubaccountDeposits\x12:.injective.exchange.v1beta1.QuerySubaccountDepositsRequest\x1a;.injective.exchange.v1beta1.QuerySubaccountDepositsResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/injective/exchange/v1beta1/exchange/subaccountDeposits\x12\xca\x01\n\x11SubaccountDeposit\x12\x39.injective.exchange.v1beta1.QuerySubaccountDepositRequest\x1a:.injective.exchange.v1beta1.QuerySubaccountDepositResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/injective/exchange/v1beta1/exchange/subaccountDeposit\x12\xc6\x01\n\x10\x45xchangeBalances\x12\x38.injective.exchange.v1beta1.QueryExchangeBalancesRequest\x1a\x39.injective.exchange.v1beta1.QueryExchangeBalancesResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/injective/exchange/v1beta1/exchange/exchangeBalances\x12\xcc\x01\n\x0f\x41ggregateVolume\x12\x37.injective.exchange.v1beta1.QueryAggregateVolumeRequest\x1a\x38.injective.exchange.v1beta1.QueryAggregateVolumeResponse\"F\x82\xd3\xe4\x93\x02@\x12>/injective/exchange/v1beta1/exchange/aggregateVolume/{account}\x12\xc6\x01\n\x10\x41ggregateVolumes\x12\x38.injective.exchange.v1beta1.QueryAggregateVolumesRequest\x1a\x39.injective.exchange.v1beta1.QueryAggregateVolumesResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/injective/exchange/v1beta1/exchange/aggregateVolumes\x12\xe6\x01\n\x15\x41ggregateMarketVolume\x12=.injective.exchange.v1beta1.QueryAggregateMarketVolumeRequest\x1a>.injective.exchange.v1beta1.QueryAggregateMarketVolumeResponse\"N\x82\xd3\xe4\x93\x02H\x12\x46/injective/exchange/v1beta1/exchange/aggregateMarketVolume/{market_id}\x12\xde\x01\n\x16\x41ggregateMarketVolumes\x12>.injective.exchange.v1beta1.QueryAggregateMarketVolumesRequest\x1a?.injective.exchange.v1beta1.QueryAggregateMarketVolumesResponse\"C\x82\xd3\xe4\x93\x02=\x12;/injective/exchange/v1beta1/exchange/aggregateMarketVolumes\x12\xbf\x01\n\x0c\x44\x65nomDecimal\x12\x34.injective.exchange.v1beta1.QueryDenomDecimalRequest\x1a\x35.injective.exchange.v1beta1.QueryDenomDecimalResponse\"B\x82\xd3\xe4\x93\x02<\x12:/injective/exchange/v1beta1/exchange/denom_decimal/{denom}\x12\xbb\x01\n\rDenomDecimals\x12\x35.injective.exchange.v1beta1.QueryDenomDecimalsRequest\x1a\x36.injective.exchange.v1beta1.QueryDenomDecimalsResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/injective/exchange/v1beta1/exchange/denom_decimals\x12\xaa\x01\n\x0bSpotMarkets\x12\x33.injective.exchange.v1beta1.QuerySpotMarketsRequest\x1a\x34.injective.exchange.v1beta1.QuerySpotMarketsResponse\"0\x82\xd3\xe4\x93\x02*\x12(/injective/exchange/v1beta1/spot/markets\x12\xb3\x01\n\nSpotMarket\x12\x32.injective.exchange.v1beta1.QuerySpotMarketRequest\x1a\x33.injective.exchange.v1beta1.QuerySpotMarketResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/injective/exchange/v1beta1/spot/markets/{market_id}\x12\xbb\x01\n\x0f\x46ullSpotMarkets\x12\x37.injective.exchange.v1beta1.QueryFullSpotMarketsRequest\x1a\x38.injective.exchange.v1beta1.QueryFullSpotMarketsResponse\"5\x82\xd3\xe4\x93\x02/\x12-/injective/exchange/v1beta1/spot/full_markets\x12\xc3\x01\n\x0e\x46ullSpotMarket\x12\x36.injective.exchange.v1beta1.QueryFullSpotMarketRequest\x1a\x37.injective.exchange.v1beta1.QueryFullSpotMarketResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/injective/exchange/v1beta1/spot/full_market/{market_id}\x12\xbe\x01\n\rSpotOrderbook\x12\x35.injective.exchange.v1beta1.QuerySpotOrderbookRequest\x1a\x36.injective.exchange.v1beta1.QuerySpotOrderbookResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/injective/exchange/v1beta1/spot/orderbook/{market_id}\x12\xd4\x01\n\x10TraderSpotOrders\x12\x38.injective.exchange.v1beta1.QueryTraderSpotOrdersRequest\x1a\x39.injective.exchange.v1beta1.QueryTraderSpotOrdersResponse\"K\x82\xd3\xe4\x93\x02\x45\x12\x43/injective/exchange/v1beta1/spot/orders/{market_id}/{subaccount_id}\x12\xf6\x01\n\x18\x41\x63\x63ountAddressSpotOrders\x12@.injective.exchange.v1beta1.QueryAccountAddressSpotOrdersRequest\x1a\x41.injective.exchange.v1beta1.QueryAccountAddressSpotOrdersResponse\"U\x82\xd3\xe4\x93\x02O\x12M/injective/exchange/v1beta1/spot/orders/{market_id}/account/{account_address}\x12\xe4\x01\n\x12SpotOrdersByHashes\x12:.injective.exchange.v1beta1.QuerySpotOrdersByHashesRequest\x1a;.injective.exchange.v1beta1.QuerySpotOrdersByHashesResponse\"U\x82\xd3\xe4\x93\x02O\x12M/injective/exchange/v1beta1/spot/orders_by_hashes/{market_id}/{subaccount_id}\x12\xc3\x01\n\x10SubaccountOrders\x12\x38.injective.exchange.v1beta1.QuerySubaccountOrdersRequest\x1a\x39.injective.exchange.v1beta1.QuerySubaccountOrdersResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/injective/exchange/v1beta1/orders/{subaccount_id}\x12\xe7\x01\n\x19TraderSpotTransientOrders\x12\x38.injective.exchange.v1beta1.QueryTraderSpotOrdersRequest\x1a\x39.injective.exchange.v1beta1.QueryTraderSpotOrdersResponse\"U\x82\xd3\xe4\x93\x02O\x12M/injective/exchange/v1beta1/spot/transient_orders/{market_id}/{subaccount_id}\x12\xd5\x01\n\x12SpotMidPriceAndTOB\x12:.injective.exchange.v1beta1.QuerySpotMidPriceAndTOBRequest\x1a;.injective.exchange.v1beta1.QuerySpotMidPriceAndTOBResponse\"F\x82\xd3\xe4\x93\x02@\x12>/injective/exchange/v1beta1/spot/mid_price_and_tob/{market_id}\x12\xed\x01\n\x18\x44\x65rivativeMidPriceAndTOB\x12@.injective.exchange.v1beta1.QueryDerivativeMidPriceAndTOBRequest\x1a\x41.injective.exchange.v1beta1.QueryDerivativeMidPriceAndTOBResponse\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/injective/exchange/v1beta1/derivative/mid_price_and_tob/{market_id}\x12\xd6\x01\n\x13\x44\x65rivativeOrderbook\x12;.injective.exchange.v1beta1.QueryDerivativeOrderbookRequest\x1a<.injective.exchange.v1beta1.QueryDerivativeOrderbookResponse\"D\x82\xd3\xe4\x93\x02>\x12</injective/exchange/v1beta1/derivative/orderbook/{market_id}\x12\xec\x01\n\x16TraderDerivativeOrders\x12>.injective.exchange.v1beta1.QueryTraderDerivativeOrdersRequest\x1a?.injective.exchange.v1beta1.QueryTraderDerivativeOrdersResponse\"Q\x82\xd3\xe4\x93\x02K\x12I/injective/exchange/v1beta1/derivative/orders/{market_id}/{subaccount_id}\x12\x8e\x02\n\x1e\x41\x63\x63ountAddressDerivativeOrders\x12\x46.injective.exchange.v1beta1.QueryAccountAddressDerivativeOrdersRequest\x1aG.injective.exchange.v1beta1.QueryAccountAddressDerivativeOrdersResponse\"[\x82\xd3\xe4\x93\x02U\x12S/injective/exchange/v1beta1/derivative/orders/{market_id}/account/{account_address}\x12\xfc\x01\n\x18\x44\x65rivativeOrdersByHashes\x12@.injective.exchange.v1beta1.QueryDerivativeOrdersByHashesRequest\x1a\x41.injective.exchange.v1beta1.QueryDerivativeOrdersByHashesResponse\"[\x82\xd3\xe4\x93\x02U\x12S/injective/exchange/v1beta1/derivative/orders_by_hashes/{market_id}/{subaccount_id}\x12\xff\x01\n\x1fTraderDerivativeTransientOrders\x12>.injective.exchange.v1beta1.QueryTraderDerivativeOrdersRequest\x1a?.injective.exchange.v1beta1.QueryTraderDerivativeOrdersResponse\"[\x82\xd3\xe4\x93\x02U\x12S/injective/exchange/v1beta1/derivative/transient_orders/{market_id}/{subaccount_id}\x12\xc2\x01\n\x11\x44\x65rivativeMarkets\x12\x39.injective.exchange.v1beta1.QueryDerivativeMarketsRequest\x1a:.injective.exchange.v1beta1.QueryDerivativeMarketsResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./injective/exchange/v1beta1/derivative/markets\x12\xcb\x01\n\x10\x44\x65rivativeMarket\x12\x38.injective.exchange.v1beta1.QueryDerivativeMarketRequest\x1a\x39.injective.exchange.v1beta1.QueryDerivativeMarketResponse\"B\x82\xd3\xe4\x93\x02<\x12:/injective/exchange/v1beta1/derivative/markets/{market_id}\x12\xe7\x01\n\x17\x44\x65rivativeMarketAddress\x12?.injective.exchange.v1beta1.QueryDerivativeMarketAddressRequest\x1a@.injective.exchange.v1beta1.QueryDerivativeMarketAddressResponse\"I\x82\xd3\xe4\x93\x02\x43\x12\x41/injective/exchange/v1beta1/derivative/market_address/{market_id}\x12\xd1\x01\n\x14SubaccountTradeNonce\x12<.injective.exchange.v1beta1.QuerySubaccountTradeNonceRequest\x1a=.injective.exchange.v1beta1.QuerySubaccountTradeNonceResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/injective/exchange/v1beta1/exchange/{subaccount_id}\x12\xb2\x01\n\x13\x45xchangeModuleState\x12\x33.injective.exchange.v1beta1.QueryModuleStateRequest\x1a\x34.injective.exchange.v1beta1.QueryModuleStateResponse\"0\x82\xd3\xe4\x93\x02*\x12(/injective/exchange/v1beta1/module_state\x12\xa1\x01\n\tPositions\x12\x31.injective.exchange.v1beta1.QueryPositionsRequest\x1a\x32.injective.exchange.v1beta1.QueryPositionsResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/injective/exchange/v1beta1/positions\x12\xcf\x01\n\x13SubaccountPositions\x12;.injective.exchange.v1beta1.QuerySubaccountPositionsRequest\x1a<.injective.exchange.v1beta1.QuerySubaccountPositionsResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/injective/exchange/v1beta1/positions/{subaccount_id}\x12\xf0\x01\n\x1aSubaccountPositionInMarket\x12\x42.injective.exchange.v1beta1.QuerySubaccountPositionInMarketRequest\x1a\x43.injective.exchange.v1beta1.QuerySubaccountPositionInMarketResponse\"I\x82\xd3\xe4\x93\x02\x43\x12\x41/injective/exchange/v1beta1/positions/{subaccount_id}/{market_id}\x12\x95\x02\n#SubaccountEffectivePositionInMarket\x12K.injective.exchange.v1beta1.QuerySubaccountEffectivePositionInMarketRequest\x1aL.injective.exchange.v1beta1.QuerySubaccountEffectivePositionInMarketResponse\"S\x82\xd3\xe4\x93\x02M\x12K/injective/exchange/v1beta1/effective_positions/{subaccount_id}/{market_id}\x12\xd7\x01\n\x13PerpetualMarketInfo\x12;.injective.exchange.v1beta1.QueryPerpetualMarketInfoRequest\x1a<.injective.exchange.v1beta1.QueryPerpetualMarketInfoResponse\"E\x82\xd3\xe4\x93\x02?\x12=/injective/exchange/v1beta1/perpetual_market_info/{market_id}\x12\xe0\x01\n\x17\x45xpiryFuturesMarketInfo\x12?.injective.exchange.v1beta1.QueryExpiryFuturesMarketInfoRequest\x1a@.injective.exchange.v1beta1.QueryExpiryFuturesMarketInfoResponse\"B\x82\xd3\xe4\x93\x02<\x12:/injective/exchange/v1beta1/expiry_market_info/{market_id}\x12\xe3\x01\n\x16PerpetualMarketFunding\x12>.injective.exchange.v1beta1.QueryPerpetualMarketFundingRequest\x1a?.injective.exchange.v1beta1.QueryPerpetualMarketFundingResponse\"H\x82\xd3\xe4\x93\x02\x42\x12@/injective/exchange/v1beta1/perpetual_market_funding/{market_id}\x12\xe0\x01\n\x17SubaccountOrderMetadata\x12?.injective.exchange.v1beta1.QuerySubaccountOrderMetadataRequest\x1a@.injective.exchange.v1beta1.QuerySubaccountOrderMetadataResponse\"B\x82\xd3\xe4\x93\x02<\x12:/injective/exchange/v1beta1/order_metadata/{subaccount_id}\x12\xc3\x01\n\x11TradeRewardPoints\x12\x39.injective.exchange.v1beta1.QueryTradeRewardPointsRequest\x1a:.injective.exchange.v1beta1.QueryTradeRewardPointsResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//injective/exchange/v1beta1/trade_reward_points\x12\xd2\x01\n\x18PendingTradeRewardPoints\x12\x39.injective.exchange.v1beta1.QueryTradeRewardPointsRequest\x1a:.injective.exchange.v1beta1.QueryTradeRewardPointsResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/injective/exchange/v1beta1/pending_trade_reward_points\x12\xcb\x01\n\x13TradeRewardCampaign\x12;.injective.exchange.v1beta1.QueryTradeRewardCampaignRequest\x1a<.injective.exchange.v1beta1.QueryTradeRewardCampaignResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/injective/exchange/v1beta1/trade_reward_campaign\x12\xe2\x01\n\x16\x46\x65\x65\x44iscountAccountInfo\x12>.injective.exchange.v1beta1.QueryFeeDiscountAccountInfoRequest\x1a?.injective.exchange.v1beta1.QueryFeeDiscountAccountInfoResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/injective/exchange/v1beta1/fee_discount_account_info/{account}\x12\xcb\x01\n\x13\x46\x65\x65\x44iscountSchedule\x12;.injective.exchange.v1beta1.QueryFeeDiscountScheduleRequest\x1a<.injective.exchange.v1beta1.QueryFeeDiscountScheduleResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/injective/exchange/v1beta1/fee_discount_schedule\x12\xd0\x01\n\x11\x42\x61lanceMismatches\x12\x39.injective.exchange.v1beta1.QueryBalanceMismatchesRequest\x1a:.injective.exchange.v1beta1.QueryBalanceMismatchesResponse\"D\x82\xd3\xe4\x93\x02>\x12</injective/exchange/v1beta1/balance_mismatches/{dust_factor}\x12\xdd\x01\n\x17\x42\x61lanceWithBalanceHolds\x12?.injective.exchange.v1beta1.QueryBalanceWithBalanceHoldsRequest\x1a@.injective.exchange.v1beta1.QueryBalanceWithBalanceHoldsResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/injective/exchange/v1beta1/balances_with_balance_holds\x12\xdf\x01\n\x19\x46\x65\x65\x44iscountTierStatistics\x12\x41.injective.exchange.v1beta1.QueryFeeDiscountTierStatisticsRequest\x1a\x42.injective.exchange.v1beta1.QueryFeeDiscountTierStatisticsResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/injective/exchange/v1beta1/fee_discount_tier_stats\x12\xad\x01\n\x0eMitoVaultInfos\x12\x31.injective.exchange.v1beta1.MitoVaultInfosRequest\x1a\x32.injective.exchange.v1beta1.MitoVaultInfosResponse\"4\x82\xd3\xe4\x93\x02.\x12,/injective/exchange/v1beta1/mito_vault_infos\x12\xd4\x01\n\x16QueryMarketIDFromVault\x12\x39.injective.exchange.v1beta1.QueryMarketIDFromVaultRequest\x1a:.injective.exchange.v1beta1.QueryMarketIDFromVaultResponse\"C\x82\xd3\xe4\x93\x02=\x12;/injective/exchange/v1beta1/vault_market_id/{vault_address}\x12\xd7\x01\n\x16HistoricalTradeRecords\x12>.injective.exchange.v1beta1.QueryHistoricalTradeRecordsRequest\x1a?.injective.exchange.v1beta1.QueryHistoricalTradeRecordsResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/injective/exchange/v1beta1/historical_trade_records\x12\xd7\x01\n\x13IsOptedOutOfRewards\x12;.injective.exchange.v1beta1.QueryIsOptedOutOfRewardsRequest\x1a<.injective.exchange.v1beta1.QueryIsOptedOutOfRewardsResponse\"E\x82\xd3\xe4\x93\x02?\x12=/injective/exchange/v1beta1/is_opted_out_of_rewards/{account}\x12\xe5\x01\n\x19OptedOutOfRewardsAccounts\x12\x41.injective.exchange.v1beta1.QueryOptedOutOfRewardsAccountsRequest\x1a\x42.injective.exchange.v1beta1.QueryOptedOutOfRewardsAccountsResponse\"A\x82\xd3\xe4\x93\x02;\x12\x39/injective/exchange/v1beta1/opted_out_of_rewards_accounts\x12\xca\x01\n\x10MarketVolatility\x12\x38.injective.exchange.v1beta1.QueryMarketVolatilityRequest\x1a\x39.injective.exchange.v1beta1.QueryMarketVolatilityResponse\"A\x82\xd3\xe4\x93\x02;\x12\x39/injective/exchange/v1beta1/market_volatility/{market_id}\x12\xc1\x01\n\x14\x42inaryOptionsMarkets\x12\x35.injective.exchange.v1beta1.QueryBinaryMarketsRequest\x1a\x36.injective.exchange.v1beta1.QueryBinaryMarketsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/injective/exchange/v1beta1/binary_options/markets\x12\x99\x02\n!TraderDerivativeConditionalOrders\x12I.injective.exchange.v1beta1.QueryTraderDerivativeConditionalOrdersRequest\x1aJ.injective.exchange.v1beta1.QueryTraderDerivativeConditionalOrdersResponse\"]\x82\xd3\xe4\x93\x02W\x12U/injective/exchange/v1beta1/derivative/orders/conditional/{market_id}/{subaccount_id}\x12\xfe\x01\n\"MarketAtomicExecutionFeeMultiplier\x12J.injective.exchange.v1beta1.QueryMarketAtomicExecutionFeeMultiplierRequest\x1aK.injective.exchange.v1beta1.QueryMarketAtomicExecutionFeeMultiplierResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/injective/exchange/v1beta1/atomic_order_fee_multiplier\x12\xc9\x01\n\x10\x41\x63tiveStakeGrant\x12\x38.injective.exchange.v1beta1.QueryActiveStakeGrantRequest\x1a\x39.injective.exchange.v1beta1.QueryActiveStakeGrantResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/injective/exchange/v1beta1/active_stake_grant/{grantee}\x12\xda\x01\n\x12GrantAuthorization\x12:.injective.exchange.v1beta1.QueryGrantAuthorizationRequest\x1a;.injective.exchange.v1beta1.QueryGrantAuthorizationResponse\"K\x82\xd3\xe4\x93\x02\x45\x12\x43/injective/exchange/v1beta1/grant_authorization/{granter}/{grantee}\x12\xd4\x01\n\x13GrantAuthorizations\x12;.injective.exchange.v1beta1.QueryGrantAuthorizationsRequest\x1a<.injective.exchange.v1beta1.QueryGrantAuthorizationsResponse\"B\x82\xd3\xe4\x93\x02<\x12:/injective/exchange/v1beta1/grant_authorizations/{granter}\x12\xbe\x01\n\rMarketBalance\x12\x35.injective.exchange.v1beta1.QueryMarketBalanceRequest\x1a\x36.injective.exchange.v1beta1.QueryMarketBalanceResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/injective/exchange/v1beta1/market_balance/{market_id}\x12\xb6\x01\n\x0eMarketBalances\x12\x36.injective.exchange.v1beta1.QueryMarketBalancesRequest\x1a\x37.injective.exchange.v1beta1.QueryMarketBalancesResponse\"3\x82\xd3\xe4\x93\x02-\x12+/injective/exchange/v1beta1/market_balances\x12\xc7\x01\n\x10\x44\x65nomMinNotional\x12\x38.injective.exchange.v1beta1.QueryDenomMinNotionalRequest\x1a\x39.injective.exchange.v1beta1.QueryDenomMinNotionalResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/injective/exchange/v1beta1/denom_min_notional/{denom}\x12\xc3\x01\n\x11\x44\x65nomMinNotionals\x12\x39.injective.exchange.v1beta1.QueryDenomMinNotionalsRequest\x1a:.injective.exchange.v1beta1.QueryDenomMinNotionalsResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//injective/exchange/v1beta1/denom_min_notionalsB\x86\x02\n\x1e\x63om.injective.exchange.v1beta1B\nQueryProtoP\x01ZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/types\xa2\x02\x03IEX\xaa\x02\x1aInjective.Exchange.V1beta1\xca\x02\x1aInjective\\Exchange\\V1beta1\xe2\x02&Injective\\Exchange\\V1beta1\\GPBMetadata\xea\x02\x1cInjective::Exchange::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.exchange.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036com.injective.exchange.v1beta1B\nQueryProtoP\001ZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/types\242\002\003IEX\252\002\032Injective.Exchange.V1beta1\312\002\032Injective\\Exchange\\V1beta1\342\002&Injective\\Exchange\\V1beta1\\GPBMetadata\352\002\034Injective::Exchange::V1beta1'
  _globals['_QUERYEXCHANGEPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYEXCHANGEPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYSUBACCOUNTDEPOSITSREQUEST'].fields_by_name['subaccount']._loaded_options = None
  _globals['_QUERYSUBACCOUNTDEPOSITSREQUEST'].fields_by_name['subaccount']._serialized_options = b'\310\336\037\001'
  _globals['_QUERYSUBACCOUNTDEPOSITSRESPONSE_DEPOSITSENTRY']._loaded_options = None
  _globals['_QUERYSUBACCOUNTDEPOSITSRESPONSE_DEPOSITSENTRY']._serialized_options = b'8\001'
  _globals['_QUERYEXCHANGEBALANCESRESPONSE'].fields_by_name['balances']._loaded_options = None
  _globals['_QUERYEXCHANGEBALANCESRESPONSE'].fields_by_name['balances']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYAGGREGATEMARKETVOLUMERESPONSE'].fields_by_name['volume']._loaded_options = None
  _globals['_QUERYAGGREGATEMARKETVOLUMERESPONSE'].fields_by_name['volume']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYDENOMDECIMALSRESPONSE'].fields_by_name['denom_decimals']._loaded_options = None
  _globals['_QUERYDENOMDECIMALSRESPONSE'].fields_by_name['denom_decimals']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYSPOTORDERBOOKREQUEST'].fields_by_name['limit_cumulative_notional']._loaded_options = None
  _globals['_QUERYSPOTORDERBOOKREQUEST'].fields_by_name['limit_cumulative_notional']._serialized_options = b'\310\336\037\001\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYSPOTORDERBOOKREQUEST'].fields_by_name['limit_cumulative_quantity']._loaded_options = None
  _globals['_QUERYSPOTORDERBOOKREQUEST'].fields_by_name['limit_cumulative_quantity']._serialized_options = b'\310\336\037\001\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_FULLSPOTMARKET'].fields_by_name['mid_price_and_tob']._loaded_options = None
  _globals['_FULLSPOTMARKET'].fields_by_name['mid_price_and_tob']._serialized_options = b'\310\336\037\001'
  _globals['_TRIMMEDSPOTLIMITORDER'].fields_by_name['price']._loaded_options = None
  _globals['_TRIMMEDSPOTLIMITORDER'].fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_TRIMMEDSPOTLIMITORDER'].fields_by_name['quantity']._loaded_options = None
  _globals['_TRIMMEDSPOTLIMITORDER'].fields_by_name['quantity']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_TRIMMEDSPOTLIMITORDER'].fields_by_name['fillable']._loaded_options = None
  _globals['_TRIMMEDSPOTLIMITORDER'].fields_by_name['fillable']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYSPOTMIDPRICEANDTOBRESPONSE'].fields_by_name['mid_price']._loaded_options = None
  _globals['_QUERYSPOTMIDPRICEANDTOBRESPONSE'].fields_by_name['mid_price']._serialized_options = b'\310\336\037\001\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYSPOTMIDPRICEANDTOBRESPONSE'].fields_by_name['best_buy_price']._loaded_options = None
  _globals['_QUERYSPOTMIDPRICEANDTOBRESPONSE'].fields_by_name['best_buy_price']._serialized_options = b'\310\336\037\001\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYSPOTMIDPRICEANDTOBRESPONSE'].fields_by_name['best_sell_price']._loaded_options = None
  _globals['_QUERYSPOTMIDPRICEANDTOBRESPONSE'].fields_by_name['best_sell_price']._serialized_options = b'\310\336\037\001\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE'].fields_by_name['mid_price']._loaded_options = None
  _globals['_QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE'].fields_by_name['mid_price']._serialized_options = b'\310\336\037\001\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE'].fields_by_name['best_buy_price']._loaded_options = None
  _globals['_QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE'].fields_by_name['best_buy_price']._serialized_options = b'\310\336\037\001\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE'].fields_by_name['best_sell_price']._loaded_options = None
  _globals['_QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE'].fields_by_name['best_sell_price']._serialized_options = b'\310\336\037\001\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYDERIVATIVEORDERBOOKREQUEST'].fields_by_name['limit_cumulative_notional']._loaded_options = None
  _globals['_QUERYDERIVATIVEORDERBOOKREQUEST'].fields_by_name['limit_cumulative_notional']._serialized_options = b'\310\336\037\001\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST'].fields_by_name['base_amount']._loaded_options = None
  _globals['_QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST'].fields_by_name['base_amount']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST'].fields_by_name['quote_amount']._loaded_options = None
  _globals['_QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST'].fields_by_name['quote_amount']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST'].fields_by_name['reference_price']._loaded_options = None
  _globals['_QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST'].fields_by_name['reference_price']._serialized_options = b'\310\336\037\001\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYTRADERDERIVATIVEORDERSTOCANCELUPTOAMOUNTREQUEST'].fields_by_name['quote_amount']._loaded_options = None
  _globals['_QUERYTRADERDERIVATIVEORDERSTOCANCELUPTOAMOUNTREQUEST'].fields_by_name['quote_amount']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYTRADERDERIVATIVEORDERSTOCANCELUPTOAMOUNTREQUEST'].fields_by_name['reference_price']._loaded_options = None
  _globals['_QUERYTRADERDERIVATIVEORDERSTOCANCELUPTOAMOUNTREQUEST'].fields_by_name['reference_price']._serialized_options = b'\310\336\037\001\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_TRIMMEDDERIVATIVELIMITORDER'].fields_by_name['price']._loaded_options = None
  _globals['_TRIMMEDDERIVATIVELIMITORDER'].fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_TRIMMEDDERIVATIVELIMITORDER'].fields_by_name['quantity']._loaded_options = None
  _globals['_TRIMMEDDERIVATIVELIMITORDER'].fields_by_name['quantity']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_TRIMMEDDERIVATIVELIMITORDER'].fields_by_name['margin']._loaded_options = None
  _globals['_TRIMMEDDERIVATIVELIMITORDER'].fields_by_name['margin']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_TRIMMEDDERIVATIVELIMITORDER'].fields_by_name['fillable']._loaded_options = None
  _globals['_TRIMMEDDERIVATIVELIMITORDER'].fields_by_name['fillable']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_TRIMMEDDERIVATIVELIMITORDER'].fields_by_name['isBuy']._loaded_options = None
  _globals['_TRIMMEDDERIVATIVELIMITORDER'].fields_by_name['isBuy']._serialized_options = b'\352\336\037\005isBuy'
  _globals['_PRICELEVEL'].fields_by_name['price']._loaded_options = None
  _globals['_PRICELEVEL'].fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_PRICELEVEL'].fields_by_name['quantity']._loaded_options = None
  _globals['_PRICELEVEL'].fields_by_name['quantity']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_FULLDERIVATIVEMARKET'].fields_by_name['mark_price']._loaded_options = None
  _globals['_FULLDERIVATIVEMARKET'].fields_by_name['mark_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_FULLDERIVATIVEMARKET'].fields_by_name['mid_price_and_tob']._loaded_options = None
  _globals['_FULLDERIVATIVEMARKET'].fields_by_name['mid_price_and_tob']._serialized_options = b'\310\336\037\001'
  _globals['_QUERYSUBACCOUNTPOSITIONSRESPONSE'].fields_by_name['state']._loaded_options = None
  _globals['_QUERYSUBACCOUNTPOSITIONSRESPONSE'].fields_by_name['state']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYSUBACCOUNTPOSITIONINMARKETRESPONSE'].fields_by_name['state']._loaded_options = None
  _globals['_QUERYSUBACCOUNTPOSITIONINMARKETRESPONSE'].fields_by_name['state']._serialized_options = b'\310\336\037\001'
  _globals['_EFFECTIVEPOSITION'].fields_by_name['quantity']._loaded_options = None
  _globals['_EFFECTIVEPOSITION'].fields_by_name['quantity']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_EFFECTIVEPOSITION'].fields_by_name['entry_price']._loaded_options = None
  _globals['_EFFECTIVEPOSITION'].fields_by_name['entry_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_EFFECTIVEPOSITION'].fields_by_name['effective_margin']._loaded_options = None
  _globals['_EFFECTIVEPOSITION'].fields_by_name['effective_margin']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYSUBACCOUNTEFFECTIVEPOSITIONINMARKETRESPONSE'].fields_by_name['state']._loaded_options = None
  _globals['_QUERYSUBACCOUNTEFFECTIVEPOSITIONINMARKETRESPONSE'].fields_by_name['state']._serialized_options = b'\310\336\037\001'
  _globals['_QUERYPERPETUALMARKETINFORESPONSE'].fields_by_name['info']._loaded_options = None
  _globals['_QUERYPERPETUALMARKETINFORESPONSE'].fields_by_name['info']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYEXPIRYFUTURESMARKETINFORESPONSE'].fields_by_name['info']._loaded_options = None
  _globals['_QUERYEXPIRYFUTURESMARKETINFORESPONSE'].fields_by_name['info']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYPERPETUALMARKETFUNDINGRESPONSE'].fields_by_name['state']._loaded_options = None
  _globals['_QUERYPERPETUALMARKETFUNDINGRESPONSE'].fields_by_name['state']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYSUBACCOUNTORDERMETADATARESPONSE'].fields_by_name['metadata']._loaded_options = None
  _globals['_QUERYSUBACCOUNTORDERMETADATARESPONSE'].fields_by_name['metadata']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYPOSITIONSRESPONSE'].fields_by_name['state']._loaded_options = None
  _globals['_QUERYPOSITIONSRESPONSE'].fields_by_name['state']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYTRADEREWARDPOINTSRESPONSE'].fields_by_name['account_trade_reward_points']._loaded_options = None
  _globals['_QUERYTRADEREWARDPOINTSRESPONSE'].fields_by_name['account_trade_reward_points']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYTRADEREWARDCAMPAIGNRESPONSE'].fields_by_name['total_trade_reward_points']._loaded_options = None
  _globals['_QUERYTRADEREWARDCAMPAIGNRESPONSE'].fields_by_name['total_trade_reward_points']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYTRADEREWARDCAMPAIGNRESPONSE'].fields_by_name['pending_total_trade_reward_points']._loaded_options = None
  _globals['_QUERYTRADEREWARDCAMPAIGNRESPONSE'].fields_by_name['pending_total_trade_reward_points']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_BALANCEMISMATCH'].fields_by_name['available']._loaded_options = None
  _globals['_BALANCEMISMATCH'].fields_by_name['available']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_BALANCEMISMATCH'].fields_by_name['total']._loaded_options = None
  _globals['_BALANCEMISMATCH'].fields_by_name['total']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_BALANCEMISMATCH'].fields_by_name['balance_hold']._loaded_options = None
  _globals['_BALANCEMISMATCH'].fields_by_name['balance_hold']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_BALANCEMISMATCH'].fields_by_name['expected_total']._loaded_options = None
  _globals['_BALANCEMISMATCH'].fields_by_name['expected_total']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_BALANCEMISMATCH'].fields_by_name['difference']._loaded_options = None
  _globals['_BALANCEMISMATCH'].fields_by_name['difference']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_BALANCEWITHMARGINHOLD'].fields_by_name['available']._loaded_options = None
  _globals['_BALANCEWITHMARGINHOLD'].fields_by_name['available']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_BALANCEWITHMARGINHOLD'].fields_by_name['total']._loaded_options = None
  _globals['_BALANCEWITHMARGINHOLD'].fields_by_name['total']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_BALANCEWITHMARGINHOLD'].fields_by_name['balance_hold']._loaded_options = None
  _globals['_BALANCEWITHMARGINHOLD'].fields_by_name['balance_hold']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYMARKETVOLATILITYRESPONSE'].fields_by_name['volatility']._loaded_options = None
  _globals['_QUERYMARKETVOLATILITYRESPONSE'].fields_by_name['volatility']._serialized_options = b'\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_TRIMMEDDERIVATIVECONDITIONALORDER'].fields_by_name['price']._loaded_options = None
  _globals['_TRIMMEDDERIVATIVECONDITIONALORDER'].fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_TRIMMEDDERIVATIVECONDITIONALORDER'].fields_by_name['quantity']._loaded_options = None
  _globals['_TRIMMEDDERIVATIVECONDITIONALORDER'].fields_by_name['quantity']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_TRIMMEDDERIVATIVECONDITIONALORDER'].fields_by_name['margin']._loaded_options = None
  _globals['_TRIMMEDDERIVATIVECONDITIONALORDER'].fields_by_name['margin']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_TRIMMEDDERIVATIVECONDITIONALORDER'].fields_by_name['triggerPrice']._loaded_options = None
  _globals['_TRIMMEDDERIVATIVECONDITIONALORDER'].fields_by_name['triggerPrice']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_TRIMMEDDERIVATIVECONDITIONALORDER'].fields_by_name['isBuy']._loaded_options = None
  _globals['_TRIMMEDDERIVATIVECONDITIONALORDER'].fields_by_name['isBuy']._serialized_options = b'\352\336\037\005isBuy'
  _globals['_TRIMMEDDERIVATIVECONDITIONALORDER'].fields_by_name['isLimit']._loaded_options = None
  _globals['_TRIMMEDDERIVATIVECONDITIONALORDER'].fields_by_name['isLimit']._serialized_options = b'\352\336\037\007isLimit'
  _globals['_TRIMMEDLIMITORDER'].fields_by_name['price']._loaded_options = None
  _globals['_TRIMMEDLIMITORDER'].fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_TRIMMEDLIMITORDER'].fields_by_name['quantity']._loaded_options = None
  _globals['_TRIMMEDLIMITORDER'].fields_by_name['quantity']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYMARKETATOMICEXECUTIONFEEMULTIPLIERRESPONSE'].fields_by_name['multiplier']._loaded_options = None
  _globals['_QUERYMARKETATOMICEXECUTIONFEEMULTIPLIERRESPONSE'].fields_by_name['multiplier']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYGRANTAUTHORIZATIONRESPONSE'].fields_by_name['amount']._loaded_options = None
  _globals['_QUERYGRANTAUTHORIZATIONRESPONSE'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_QUERYGRANTAUTHORIZATIONSRESPONSE'].fields_by_name['total_grant_amount']._loaded_options = None
  _globals['_QUERYGRANTAUTHORIZATIONSRESPONSE'].fields_by_name['total_grant_amount']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_MARKETBALANCE'].fields_by_name['balance']._loaded_options = None
  _globals['_MARKETBALANCE'].fields_by_name['balance']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYDENOMMINNOTIONALRESPONSE'].fields_by_name['amount']._loaded_options = None
  _globals['_QUERYDENOMMINNOTIONALRESPONSE'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERY'].methods_by_name['L3DerivativeOrderBook']._loaded_options = None
  _globals['_QUERY'].methods_by_name['L3DerivativeOrderBook']._serialized_options = b'\202\323\344\223\002@\022>/injective/exchange/v1beta1/derivative/L3OrderBook/{market_id}'
  _globals['_QUERY'].methods_by_name['L3SpotOrderBook']._loaded_options = None
  _globals['_QUERY'].methods_by_name['L3SpotOrderBook']._serialized_options = b'\202\323\344\223\002:\0228/injective/exchange/v1beta1/spot/L3OrderBook/{market_id}'
  _globals['_QUERY'].methods_by_name['QueryExchangeParams']._loaded_options = None
  _globals['_QUERY'].methods_by_name['QueryExchangeParams']._serialized_options = b'\202\323\344\223\002,\022*/injective/exchange/v1beta1/exchangeParams'
  _globals['_QUERY'].methods_by_name['SubaccountDeposits']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SubaccountDeposits']._serialized_options = b'\202\323\344\223\0029\0227/injective/exchange/v1beta1/exchange/subaccountDeposits'
  _globals['_QUERY'].methods_by_name['SubaccountDeposit']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SubaccountDeposit']._serialized_options = b'\202\323\344\223\0028\0226/injective/exchange/v1beta1/exchange/subaccountDeposit'
  _globals['_QUERY'].methods_by_name['ExchangeBalances']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ExchangeBalances']._serialized_options = b'\202\323\344\223\0027\0225/injective/exchange/v1beta1/exchange/exchangeBalances'
  _globals['_QUERY'].methods_by_name['AggregateVolume']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AggregateVolume']._serialized_options = b'\202\323\344\223\002@\022>/injective/exchange/v1beta1/exchange/aggregateVolume/{account}'
  _globals['_QUERY'].methods_by_name['AggregateVolumes']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AggregateVolumes']._serialized_options = b'\202\323\344\223\0027\0225/injective/exchange/v1beta1/exchange/aggregateVolumes'
  _globals['_QUERY'].methods_by_name['AggregateMarketVolume']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AggregateMarketVolume']._serialized_options = b'\202\323\344\223\002H\022F/injective/exchange/v1beta1/exchange/aggregateMarketVolume/{market_id}'
  _globals['_QUERY'].methods_by_name['AggregateMarketVolumes']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AggregateMarketVolumes']._serialized_options = b'\202\323\344\223\002=\022;/injective/exchange/v1beta1/exchange/aggregateMarketVolumes'
  _globals['_QUERY'].methods_by_name['DenomDecimal']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DenomDecimal']._serialized_options = b'\202\323\344\223\002<\022:/injective/exchange/v1beta1/exchange/denom_decimal/{denom}'
  _globals['_QUERY'].methods_by_name['DenomDecimals']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DenomDecimals']._serialized_options = b'\202\323\344\223\0025\0223/injective/exchange/v1beta1/exchange/denom_decimals'
  _globals['_QUERY'].methods_by_name['SpotMarkets']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SpotMarkets']._serialized_options = b'\202\323\344\223\002*\022(/injective/exchange/v1beta1/spot/markets'
  _globals['_QUERY'].methods_by_name['SpotMarket']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SpotMarket']._serialized_options = b'\202\323\344\223\0026\0224/injective/exchange/v1beta1/spot/markets/{market_id}'
  _globals['_QUERY'].methods_by_name['FullSpotMarkets']._loaded_options = None
  _globals['_QUERY'].methods_by_name['FullSpotMarkets']._serialized_options = b'\202\323\344\223\002/\022-/injective/exchange/v1beta1/spot/full_markets'
  _globals['_QUERY'].methods_by_name['FullSpotMarket']._loaded_options = None
  _globals['_QUERY'].methods_by_name['FullSpotMarket']._serialized_options = b'\202\323\344\223\002:\0228/injective/exchange/v1beta1/spot/full_market/{market_id}'
  _globals['_QUERY'].methods_by_name['SpotOrderbook']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SpotOrderbook']._serialized_options = b'\202\323\344\223\0028\0226/injective/exchange/v1beta1/spot/orderbook/{market_id}'
  _globals['_QUERY'].methods_by_name['TraderSpotOrders']._loaded_options = None
  _globals['_QUERY'].methods_by_name['TraderSpotOrders']._serialized_options = b'\202\323\344\223\002E\022C/injective/exchange/v1beta1/spot/orders/{market_id}/{subaccount_id}'
  _globals['_QUERY'].methods_by_name['AccountAddressSpotOrders']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AccountAddressSpotOrders']._serialized_options = b'\202\323\344\223\002O\022M/injective/exchange/v1beta1/spot/orders/{market_id}/account/{account_address}'
  _globals['_QUERY'].methods_by_name['SpotOrdersByHashes']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SpotOrdersByHashes']._serialized_options = b'\202\323\344\223\002O\022M/injective/exchange/v1beta1/spot/orders_by_hashes/{market_id}/{subaccount_id}'
  _globals['_QUERY'].methods_by_name['SubaccountOrders']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SubaccountOrders']._serialized_options = b'\202\323\344\223\0024\0222/injective/exchange/v1beta1/orders/{subaccount_id}'
  _globals['_QUERY'].methods_by_name['TraderSpotTransientOrders']._loaded_options = None
  _globals['_QUERY'].methods_by_name['TraderSpotTransientOrders']._serialized_options = b'\202\323\344\223\002O\022M/injective/exchange/v1beta1/spot/transient_orders/{market_id}/{subaccount_id}'
  _globals['_QUERY'].methods_by_name['SpotMidPriceAndTOB']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SpotMidPriceAndTOB']._serialized_options = b'\202\323\344\223\002@\022>/injective/exchange/v1beta1/spot/mid_price_and_tob/{market_id}'
  _globals['_QUERY'].methods_by_name['DerivativeMidPriceAndTOB']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DerivativeMidPriceAndTOB']._serialized_options = b'\202\323\344\223\002F\022D/injective/exchange/v1beta1/derivative/mid_price_and_tob/{market_id}'
  _globals['_QUERY'].methods_by_name['DerivativeOrderbook']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DerivativeOrderbook']._serialized_options = b'\202\323\344\223\002>\022</injective/exchange/v1beta1/derivative/orderbook/{market_id}'
  _globals['_QUERY'].methods_by_name['TraderDerivativeOrders']._loaded_options = None
  _globals['_QUERY'].methods_by_name['TraderDerivativeOrders']._serialized_options = b'\202\323\344\223\002K\022I/injective/exchange/v1beta1/derivative/orders/{market_id}/{subaccount_id}'
  _globals['_QUERY'].methods_by_name['AccountAddressDerivativeOrders']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AccountAddressDerivativeOrders']._serialized_options = b'\202\323\344\223\002U\022S/injective/exchange/v1beta1/derivative/orders/{market_id}/account/{account_address}'
  _globals['_QUERY'].methods_by_name['DerivativeOrdersByHashes']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DerivativeOrdersByHashes']._serialized_options = b'\202\323\344\223\002U\022S/injective/exchange/v1beta1/derivative/orders_by_hashes/{market_id}/{subaccount_id}'
  _globals['_QUERY'].methods_by_name['TraderDerivativeTransientOrders']._loaded_options = None
  _globals['_QUERY'].methods_by_name['TraderDerivativeTransientOrders']._serialized_options = b'\202\323\344\223\002U\022S/injective/exchange/v1beta1/derivative/transient_orders/{market_id}/{subaccount_id}'
  _globals['_QUERY'].methods_by_name['DerivativeMarkets']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DerivativeMarkets']._serialized_options = b'\202\323\344\223\0020\022./injective/exchange/v1beta1/derivative/markets'
  _globals['_QUERY'].methods_by_name['DerivativeMarket']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DerivativeMarket']._serialized_options = b'\202\323\344\223\002<\022:/injective/exchange/v1beta1/derivative/markets/{market_id}'
  _globals['_QUERY'].methods_by_name['DerivativeMarketAddress']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DerivativeMarketAddress']._serialized_options = b'\202\323\344\223\002C\022A/injective/exchange/v1beta1/derivative/market_address/{market_id}'
  _globals['_QUERY'].methods_by_name['SubaccountTradeNonce']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SubaccountTradeNonce']._serialized_options = b'\202\323\344\223\0026\0224/injective/exchange/v1beta1/exchange/{subaccount_id}'
  _globals['_QUERY'].methods_by_name['ExchangeModuleState']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ExchangeModuleState']._serialized_options = b'\202\323\344\223\002*\022(/injective/exchange/v1beta1/module_state'
  _globals['_QUERY'].methods_by_name['Positions']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Positions']._serialized_options = b'\202\323\344\223\002\'\022%/injective/exchange/v1beta1/positions'
  _globals['_QUERY'].methods_by_name['SubaccountPositions']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SubaccountPositions']._serialized_options = b'\202\323\344\223\0027\0225/injective/exchange/v1beta1/positions/{subaccount_id}'
  _globals['_QUERY'].methods_by_name['SubaccountPositionInMarket']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SubaccountPositionInMarket']._serialized_options = b'\202\323\344\223\002C\022A/injective/exchange/v1beta1/positions/{subaccount_id}/{market_id}'
  _globals['_QUERY'].methods_by_name['SubaccountEffectivePositionInMarket']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SubaccountEffectivePositionInMarket']._serialized_options = b'\202\323\344\223\002M\022K/injective/exchange/v1beta1/effective_positions/{subaccount_id}/{market_id}'
  _globals['_QUERY'].methods_by_name['PerpetualMarketInfo']._loaded_options = None
  _globals['_QUERY'].methods_by_name['PerpetualMarketInfo']._serialized_options = b'\202\323\344\223\002?\022=/injective/exchange/v1beta1/perpetual_market_info/{market_id}'
  _globals['_QUERY'].methods_by_name['ExpiryFuturesMarketInfo']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ExpiryFuturesMarketInfo']._serialized_options = b'\202\323\344\223\002<\022:/injective/exchange/v1beta1/expiry_market_info/{market_id}'
  _globals['_QUERY'].methods_by_name['PerpetualMarketFunding']._loaded_options = None
  _globals['_QUERY'].methods_by_name['PerpetualMarketFunding']._serialized_options = b'\202\323\344\223\002B\022@/injective/exchange/v1beta1/perpetual_market_funding/{market_id}'
  _globals['_QUERY'].methods_by_name['SubaccountOrderMetadata']._loaded_options = None
  _globals['_QUERY'].methods_by_name['SubaccountOrderMetadata']._serialized_options = b'\202\323\344\223\002<\022:/injective/exchange/v1beta1/order_metadata/{subaccount_id}'
  _globals['_QUERY'].methods_by_name['TradeRewardPoints']._loaded_options = None
  _globals['_QUERY'].methods_by_name['TradeRewardPoints']._serialized_options = b'\202\323\344\223\0021\022//injective/exchange/v1beta1/trade_reward_points'
  _globals['_QUERY'].methods_by_name['PendingTradeRewardPoints']._loaded_options = None
  _globals['_QUERY'].methods_by_name['PendingTradeRewardPoints']._serialized_options = b'\202\323\344\223\0029\0227/injective/exchange/v1beta1/pending_trade_reward_points'
  _globals['_QUERY'].methods_by_name['TradeRewardCampaign']._loaded_options = None
  _globals['_QUERY'].methods_by_name['TradeRewardCampaign']._serialized_options = b'\202\323\344\223\0023\0221/injective/exchange/v1beta1/trade_reward_campaign'
  _globals['_QUERY'].methods_by_name['FeeDiscountAccountInfo']._loaded_options = None
  _globals['_QUERY'].methods_by_name['FeeDiscountAccountInfo']._serialized_options = b'\202\323\344\223\002A\022?/injective/exchange/v1beta1/fee_discount_account_info/{account}'
  _globals['_QUERY'].methods_by_name['FeeDiscountSchedule']._loaded_options = None
  _globals['_QUERY'].methods_by_name['FeeDiscountSchedule']._serialized_options = b'\202\323\344\223\0023\0221/injective/exchange/v1beta1/fee_discount_schedule'
  _globals['_QUERY'].methods_by_name['BalanceMismatches']._loaded_options = None
  _globals['_QUERY'].methods_by_name['BalanceMismatches']._serialized_options = b'\202\323\344\223\002>\022</injective/exchange/v1beta1/balance_mismatches/{dust_factor}'
  _globals['_QUERY'].methods_by_name['BalanceWithBalanceHolds']._loaded_options = None
  _globals['_QUERY'].methods_by_name['BalanceWithBalanceHolds']._serialized_options = b'\202\323\344\223\0029\0227/injective/exchange/v1beta1/balances_with_balance_holds'
  _globals['_QUERY'].methods_by_name['FeeDiscountTierStatistics']._loaded_options = None
  _globals['_QUERY'].methods_by_name['FeeDiscountTierStatistics']._serialized_options = b'\202\323\344\223\0025\0223/injective/exchange/v1beta1/fee_discount_tier_stats'
  _globals['_QUERY'].methods_by_name['MitoVaultInfos']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MitoVaultInfos']._serialized_options = b'\202\323\344\223\002.\022,/injective/exchange/v1beta1/mito_vault_infos'
  _globals['_QUERY'].methods_by_name['QueryMarketIDFromVault']._loaded_options = None
  _globals['_QUERY'].methods_by_name['QueryMarketIDFromVault']._serialized_options = b'\202\323\344\223\002=\022;/injective/exchange/v1beta1/vault_market_id/{vault_address}'
  _globals['_QUERY'].methods_by_name['HistoricalTradeRecords']._loaded_options = None
  _globals['_QUERY'].methods_by_name['HistoricalTradeRecords']._serialized_options = b'\202\323\344\223\0026\0224/injective/exchange/v1beta1/historical_trade_records'
  _globals['_QUERY'].methods_by_name['IsOptedOutOfRewards']._loaded_options = None
  _globals['_QUERY'].methods_by_name['IsOptedOutOfRewards']._serialized_options = b'\202\323\344\223\002?\022=/injective/exchange/v1beta1/is_opted_out_of_rewards/{account}'
  _globals['_QUERY'].methods_by_name['OptedOutOfRewardsAccounts']._loaded_options = None
  _globals['_QUERY'].methods_by_name['OptedOutOfRewardsAccounts']._serialized_options = b'\202\323\344\223\002;\0229/injective/exchange/v1beta1/opted_out_of_rewards_accounts'
  _globals['_QUERY'].methods_by_name['MarketVolatility']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MarketVolatility']._serialized_options = b'\202\323\344\223\002;\0229/injective/exchange/v1beta1/market_volatility/{market_id}'
  _globals['_QUERY'].methods_by_name['BinaryOptionsMarkets']._loaded_options = None
  _globals['_QUERY'].methods_by_name['BinaryOptionsMarkets']._serialized_options = b'\202\323\344\223\0024\0222/injective/exchange/v1beta1/binary_options/markets'
  _globals['_QUERY'].methods_by_name['TraderDerivativeConditionalOrders']._loaded_options = None
  _globals['_QUERY'].methods_by_name['TraderDerivativeConditionalOrders']._serialized_options = b'\202\323\344\223\002W\022U/injective/exchange/v1beta1/derivative/orders/conditional/{market_id}/{subaccount_id}'
  _globals['_QUERY'].methods_by_name['MarketAtomicExecutionFeeMultiplier']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MarketAtomicExecutionFeeMultiplier']._serialized_options = b'\202\323\344\223\0029\0227/injective/exchange/v1beta1/atomic_order_fee_multiplier'
  _globals['_QUERY'].methods_by_name['ActiveStakeGrant']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ActiveStakeGrant']._serialized_options = b'\202\323\344\223\002:\0228/injective/exchange/v1beta1/active_stake_grant/{grantee}'
  _globals['_QUERY'].methods_by_name['GrantAuthorization']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GrantAuthorization']._serialized_options = b'\202\323\344\223\002E\022C/injective/exchange/v1beta1/grant_authorization/{granter}/{grantee}'
  _globals['_QUERY'].methods_by_name['GrantAuthorizations']._loaded_options = None
  _globals['_QUERY'].methods_by_name['GrantAuthorizations']._serialized_options = b'\202\323\344\223\002<\022:/injective/exchange/v1beta1/grant_authorizations/{granter}'
  _globals['_QUERY'].methods_by_name['MarketBalance']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MarketBalance']._serialized_options = b'\202\323\344\223\0028\0226/injective/exchange/v1beta1/market_balance/{market_id}'
  _globals['_QUERY'].methods_by_name['MarketBalances']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MarketBalances']._serialized_options = b'\202\323\344\223\002-\022+/injective/exchange/v1beta1/market_balances'
  _globals['_QUERY'].methods_by_name['DenomMinNotional']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DenomMinNotional']._serialized_options = b'\202\323\344\223\0028\0226/injective/exchange/v1beta1/denom_min_notional/{denom}'
  _globals['_QUERY'].methods_by_name['DenomMinNotionals']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DenomMinNotionals']._serialized_options = b'\202\323\344\223\0021\022//injective/exchange/v1beta1/denom_min_notionals'
  _globals['_ORDERSIDE']._serialized_start=18719
  _globals['_ORDERSIDE']._serialized_end=18771
  _globals['_CANCELLATIONSTRATEGY']._serialized_start=18773
  _globals['_CANCELLATIONSTRATEGY']._serialized_end=18859
  _globals['_SUBACCOUNT']._serialized_start=246
  _globals['_SUBACCOUNT']._serialized_end=325
  _globals['_QUERYSUBACCOUNTORDERSREQUEST']._serialized_start=327
  _globals['_QUERYSUBACCOUNTORDERSREQUEST']._serialized_end=423
  _globals['_QUERYSUBACCOUNTORDERSRESPONSE']._serialized_start=426
  _globals['_QUERYSUBACCOUNTORDERSRESPONSE']._serialized_end=619
  _globals['_SUBACCOUNTORDERBOOKMETADATAWITHMARKET']._serialized_start=622
  _globals['_SUBACCOUNTORDERBOOKMETADATAWITHMARKET']._serialized_end=797
  _globals['_QUERYEXCHANGEPARAMSREQUEST']._serialized_start=799
  _globals['_QUERYEXCHANGEPARAMSREQUEST']._serialized_end=827
  _globals['_QUERYEXCHANGEPARAMSRESPONSE']._serialized_start=829
  _globals['_QUERYEXCHANGEPARAMSRESPONSE']._serialized_end=924
  _globals['_QUERYSUBACCOUNTDEPOSITSREQUEST']._serialized_start=927
  _globals['_QUERYSUBACCOUNTDEPOSITSREQUEST']._serialized_end=1074
  _globals['_QUERYSUBACCOUNTDEPOSITSRESPONSE']._serialized_start=1077
  _globals['_QUERYSUBACCOUNTDEPOSITSRESPONSE']._serialized_end=1311
  _globals['_QUERYSUBACCOUNTDEPOSITSRESPONSE_DEPOSITSENTRY']._serialized_start=1215
  _globals['_QUERYSUBACCOUNTDEPOSITSRESPONSE_DEPOSITSENTRY']._serialized_end=1311
  _globals['_QUERYEXCHANGEBALANCESREQUEST']._serialized_start=1313
  _globals['_QUERYEXCHANGEBALANCESREQUEST']._serialized_end=1343
  _globals['_QUERYEXCHANGEBALANCESRESPONSE']._serialized_start=1345
  _globals['_QUERYEXCHANGEBALANCESRESPONSE']._serialized_end=1447
  _globals['_QUERYAGGREGATEVOLUMEREQUEST']._serialized_start=1449
  _globals['_QUERYAGGREGATEVOLUMEREQUEST']._serialized_end=1504
  _globals['_QUERYAGGREGATEVOLUMERESPONSE']._serialized_start=1506
  _globals['_QUERYAGGREGATEVOLUMERESPONSE']._serialized_end=1623
  _globals['_QUERYAGGREGATEVOLUMESREQUEST']._serialized_start=1625
  _globals['_QUERYAGGREGATEVOLUMESREQUEST']._serialized_end=1714
  _globals['_QUERYAGGREGATEVOLUMESRESPONSE']._serialized_start=1717
  _globals['_QUERYAGGREGATEVOLUMESRESPONSE']._serialized_end=1966
  _globals['_QUERYAGGREGATEMARKETVOLUMEREQUEST']._serialized_start=1968
  _globals['_QUERYAGGREGATEMARKETVOLUMEREQUEST']._serialized_end=2032
  _globals['_QUERYAGGREGATEMARKETVOLUMERESPONSE']._serialized_start=2034
  _globals['_QUERYAGGREGATEMARKETVOLUMERESPONSE']._serialized_end=2142
  _globals['_QUERYDENOMDECIMALREQUEST']._serialized_start=2144
  _globals['_QUERYDENOMDECIMALREQUEST']._serialized_end=2192
  _globals['_QUERYDENOMDECIMALRESPONSE']._serialized_start=2194
  _globals['_QUERYDENOMDECIMALRESPONSE']._serialized_end=2247
  _globals['_QUERYDENOMDECIMALSREQUEST']._serialized_start=2249
  _globals['_QUERYDENOMDECIMALSREQUEST']._serialized_end=2300
  _globals['_QUERYDENOMDECIMALSRESPONSE']._serialized_start=2302
  _globals['_QUERYDENOMDECIMALSRESPONSE']._serialized_end=2418
  _globals['_QUERYAGGREGATEMARKETVOLUMESREQUEST']._serialized_start=2420
  _globals['_QUERYAGGREGATEMARKETVOLUMESREQUEST']._serialized_end=2487
  _globals['_QUERYAGGREGATEMARKETVOLUMESRESPONSE']._serialized_start=2489
  _globals['_QUERYAGGREGATEMARKETVOLUMESRESPONSE']._serialized_end=2594
  _globals['_QUERYSUBACCOUNTDEPOSITREQUEST']._serialized_start=2596
  _globals['_QUERYSUBACCOUNTDEPOSITREQUEST']._serialized_end=2686
  _globals['_QUERYSUBACCOUNTDEPOSITRESPONSE']._serialized_start=2688
  _globals['_QUERYSUBACCOUNTDEPOSITRESPONSE']._serialized_end=2785
  _globals['_QUERYSPOTMARKETSREQUEST']._serialized_start=2787
  _globals['_QUERYSPOTMARKETSREQUEST']._serialized_end=2867
  _globals['_QUERYSPOTMARKETSRESPONSE']._serialized_start=2869
  _globals['_QUERYSPOTMARKETSRESPONSE']._serialized_end=2961
  _globals['_QUERYSPOTMARKETREQUEST']._serialized_start=2963
  _globals['_QUERYSPOTMARKETREQUEST']._serialized_end=3016
  _globals['_QUERYSPOTMARKETRESPONSE']._serialized_start=3018
  _globals['_QUERYSPOTMARKETRESPONSE']._serialized_end=3107
  _globals['_QUERYSPOTORDERBOOKREQUEST']._serialized_start=3110
  _globals['_QUERYSPOTORDERBOOKREQUEST']._serialized_end=3452
  _globals['_QUERYSPOTORDERBOOKRESPONSE']._serialized_start=3455
  _globals['_QUERYSPOTORDERBOOKRESPONSE']._serialized_end=3639
  _globals['_FULLSPOTMARKET']._serialized_start=3642
  _globals['_FULLSPOTMARKET']._serialized_end=3815
  _globals['_QUERYFULLSPOTMARKETSREQUEST']._serialized_start=3818
  _globals['_QUERYFULLSPOTMARKETSREQUEST']._serialized_end=3954
  _globals['_QUERYFULLSPOTMARKETSRESPONSE']._serialized_start=3956
  _globals['_QUERYFULLSPOTMARKETSRESPONSE']._serialized_end=4056
  _globals['_QUERYFULLSPOTMARKETREQUEST']._serialized_start=4058
  _globals['_QUERYFULLSPOTMARKETREQUEST']._serialized_end=4167
  _globals['_QUERYFULLSPOTMARKETRESPONSE']._serialized_start=4169
  _globals['_QUERYFULLSPOTMARKETRESPONSE']._serialized_end=4266
  _globals['_QUERYSPOTORDERSBYHASHESREQUEST']._serialized_start=4269
  _globals['_QUERYSPOTORDERSBYHASHESREQUEST']._serialized_end=4402
  _globals['_QUERYSPOTORDERSBYHASHESRESPONSE']._serialized_start=4404
  _globals['_QUERYSPOTORDERSBYHASHESRESPONSE']._serialized_end=4512
  _globals['_QUERYTRADERSPOTORDERSREQUEST']._serialized_start=4514
  _globals['_QUERYTRADERSPOTORDERSREQUEST']._serialized_end=4610
  _globals['_QUERYACCOUNTADDRESSSPOTORDERSREQUEST']._serialized_start=4612
  _globals['_QUERYACCOUNTADDRESSSPOTORDERSREQUEST']._serialized_end=4720
  _globals['_TRIMMEDSPOTLIMITORDER']._serialized_start=4723
  _globals['_TRIMMEDSPOTLIMITORDER']._serialized_end=5006
  _globals['_QUERYTRADERSPOTORDERSRESPONSE']._serialized_start=5008
  _globals['_QUERYTRADERSPOTORDERSRESPONSE']._serialized_end=5114
  _globals['_QUERYACCOUNTADDRESSSPOTORDERSRESPONSE']._serialized_start=5116
  _globals['_QUERYACCOUNTADDRESSSPOTORDERSRESPONSE']._serialized_end=5230
  _globals['_QUERYSPOTMIDPRICEANDTOBREQUEST']._serialized_start=5232
  _globals['_QUERYSPOTMIDPRICEANDTOBREQUEST']._serialized_end=5293
  _globals['_QUERYSPOTMIDPRICEANDTOBRESPONSE']._serialized_start=5296
  _globals['_QUERYSPOTMIDPRICEANDTOBRESPONSE']._serialized_end=5547
  _globals['_QUERYDERIVATIVEMIDPRICEANDTOBREQUEST']._serialized_start=5549
  _globals['_QUERYDERIVATIVEMIDPRICEANDTOBREQUEST']._serialized_end=5616
  _globals['_QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE']._serialized_start=5619
  _globals['_QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE']._serialized_end=5876
  _globals['_QUERYDERIVATIVEORDERBOOKREQUEST']._serialized_start=5879
  _globals['_QUERYDERIVATIVEORDERBOOKREQUEST']._serialized_end=6060
  _globals['_QUERYDERIVATIVEORDERBOOKRESPONSE']._serialized_start=6063
  _globals['_QUERYDERIVATIVEORDERBOOKRESPONSE']._serialized_end=6253
  _globals['_QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST']._serialized_start=6256
  _globals['_QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST']._serialized_end=6668
  _globals['_QUERYTRADERDERIVATIVEORDERSTOCANCELUPTOAMOUNTREQUEST']._serialized_start=6671
  _globals['_QUERYTRADERDERIVATIVEORDERSTOCANCELUPTOAMOUNTREQUEST']._serialized_end=7019
  _globals['_QUERYTRADERDERIVATIVEORDERSREQUEST']._serialized_start=7021
  _globals['_QUERYTRADERDERIVATIVEORDERSREQUEST']._serialized_end=7123
  _globals['_QUERYACCOUNTADDRESSDERIVATIVEORDERSREQUEST']._serialized_start=7125
  _globals['_QUERYACCOUNTADDRESSDERIVATIVEORDERSREQUEST']._serialized_end=7239
  _globals['_TRIMMEDDERIVATIVELIMITORDER']._serialized_start=7242
  _globals['_TRIMMEDDERIVATIVELIMITORDER']._serialized_end=7603
  _globals['_QUERYTRADERDERIVATIVEORDERSRESPONSE']._serialized_start=7605
  _globals['_QUERYTRADERDERIVATIVEORDERSRESPONSE']._serialized_end=7723
  _globals['_QUERYACCOUNTADDRESSDERIVATIVEORDERSRESPONSE']._serialized_start=7725
  _globals['_QUERYACCOUNTADDRESSDERIVATIVEORDERSRESPONSE']._serialized_end=7851
  _globals['_QUERYDERIVATIVEORDERSBYHASHESREQUEST']._serialized_start=7854
  _globals['_QUERYDERIVATIVEORDERSBYHASHESREQUEST']._serialized_end=7993
  _globals['_QUERYDERIVATIVEORDERSBYHASHESRESPONSE']._serialized_start=7995
  _globals['_QUERYDERIVATIVEORDERSBYHASHESRESPONSE']._serialized_end=8115
  _globals['_QUERYDERIVATIVEMARKETSREQUEST']._serialized_start=8118
  _globals['_QUERYDERIVATIVEMARKETSREQUEST']._serialized_end=8256
  _globals['_PRICELEVEL']._serialized_start=8259
  _globals['_PRICELEVEL']._serialized_end=8395
  _globals['_PERPETUALMARKETSTATE']._serialized_start=8398
  _globals['_PERPETUALMARKETSTATE']._serialized_end=8589
  _globals['_FULLDERIVATIVEMARKET']._serialized_start=8592
  _globals['_FULLDERIVATIVEMARKET']._serialized_end=9034
  _globals['_QUERYDERIVATIVEMARKETSRESPONSE']._serialized_start=9036
  _globals['_QUERYDERIVATIVEMARKETSRESPONSE']._serialized_end=9144
  _globals['_QUERYDERIVATIVEMARKETREQUEST']._serialized_start=9146
  _globals['_QUERYDERIVATIVEMARKETREQUEST']._serialized_end=9205
  _globals['_QUERYDERIVATIVEMARKETRESPONSE']._serialized_start=9207
  _globals['_QUERYDERIVATIVEMARKETRESPONSE']._serialized_end=9312
  _globals['_QUERYDERIVATIVEMARKETADDRESSREQUEST']._serialized_start=9314
  _globals['_QUERYDERIVATIVEMARKETADDRESSREQUEST']._serialized_end=9380
  _globals['_QUERYDERIVATIVEMARKETADDRESSRESPONSE']._serialized_start=9382
  _globals['_QUERYDERIVATIVEMARKETADDRESSRESPONSE']._serialized_end=9483
  _globals['_QUERYSUBACCOUNTTRADENONCEREQUEST']._serialized_start=9485
  _globals['_QUERYSUBACCOUNTTRADENONCEREQUEST']._serialized_end=9556
  _globals['_QUERYSUBACCOUNTPOSITIONSREQUEST']._serialized_start=9558
  _globals['_QUERYSUBACCOUNTPOSITIONSREQUEST']._serialized_end=9628
  _globals['_QUERYSUBACCOUNTPOSITIONINMARKETREQUEST']._serialized_start=9630
  _globals['_QUERYSUBACCOUNTPOSITIONINMARKETREQUEST']._serialized_end=9736
  _globals['_QUERYSUBACCOUNTEFFECTIVEPOSITIONINMARKETREQUEST']._serialized_start=9738
  _globals['_QUERYSUBACCOUNTEFFECTIVEPOSITIONINMARKETREQUEST']._serialized_end=9853
  _globals['_QUERYSUBACCOUNTORDERMETADATAREQUEST']._serialized_start=9855
  _globals['_QUERYSUBACCOUNTORDERMETADATAREQUEST']._serialized_end=9929
  _globals['_QUERYSUBACCOUNTPOSITIONSRESPONSE']._serialized_start=9931
  _globals['_QUERYSUBACCOUNTPOSITIONSRESPONSE']._serialized_end=10041
  _globals['_QUERYSUBACCOUNTPOSITIONINMARKETRESPONSE']._serialized_start=10043
  _globals['_QUERYSUBACCOUNTPOSITIONINMARKETRESPONSE']._serialized_end=10150
  _globals['_EFFECTIVEPOSITION']._serialized_start=10153
  _globals['_EFFECTIVEPOSITION']._serialized_end=10412
  _globals['_QUERYSUBACCOUNTEFFECTIVEPOSITIONINMARKETRESPONSE']._serialized_start=10414
  _globals['_QUERYSUBACCOUNTEFFECTIVEPOSITIONINMARKETRESPONSE']._serialized_end=10539
  _globals['_QUERYPERPETUALMARKETINFOREQUEST']._serialized_start=10541
  _globals['_QUERYPERPETUALMARKETINFOREQUEST']._serialized_end=10603
  _globals['_QUERYPERPETUALMARKETINFORESPONSE']._serialized_start=10605
  _globals['_QUERYPERPETUALMARKETINFORESPONSE']._serialized_end=10714
  _globals['_QUERYEXPIRYFUTURESMARKETINFOREQUEST']._serialized_start=10716
  _globals['_QUERYEXPIRYFUTURESMARKETINFOREQUEST']._serialized_end=10782
  _globals['_QUERYEXPIRYFUTURESMARKETINFORESPONSE']._serialized_start=10784
  _globals['_QUERYEXPIRYFUTURESMARKETINFORESPONSE']._serialized_end=10901
  _globals['_QUERYPERPETUALMARKETFUNDINGREQUEST']._serialized_start=10903
  _globals['_QUERYPERPETUALMARKETFUNDINGREQUEST']._serialized_end=10968
  _globals['_QUERYPERPETUALMARKETFUNDINGRESPONSE']._serialized_start=10970
  _globals['_QUERYPERPETUALMARKETFUNDINGRESPONSE']._serialized_end=11087
  _globals['_QUERYSUBACCOUNTORDERMETADATARESPONSE']._serialized_start=11090
  _globals['_QUERYSUBACCOUNTORDERMETADATARESPONSE']._serialized_end=11229
  _globals['_QUERYSUBACCOUNTTRADENONCERESPONSE']._serialized_start=11231
  _globals['_QUERYSUBACCOUNTTRADENONCERESPONSE']._serialized_end=11288
  _globals['_QUERYMODULESTATEREQUEST']._serialized_start=11290
  _globals['_QUERYMODULESTATEREQUEST']._serialized_end=11315
  _globals['_QUERYMODULESTATERESPONSE']._serialized_start=11317
  _globals['_QUERYMODULESTATERESPONSE']._serialized_end=11407
  _globals['_QUERYPOSITIONSREQUEST']._serialized_start=11409
  _globals['_QUERYPOSITIONSREQUEST']._serialized_end=11432
  _globals['_QUERYPOSITIONSRESPONSE']._serialized_start=11434
  _globals['_QUERYPOSITIONSRESPONSE']._serialized_end=11534
  _globals['_QUERYTRADEREWARDPOINTSREQUEST']._serialized_start=11536
  _globals['_QUERYTRADEREWARDPOINTSREQUEST']._serialized_end=11649
  _globals['_QUERYTRADEREWARDPOINTSRESPONSE']._serialized_start=11652
  _globals['_QUERYTRADEREWARDPOINTSRESPONSE']._serialized_end=11784
  _globals['_QUERYTRADEREWARDCAMPAIGNREQUEST']._serialized_start=11786
  _globals['_QUERYTRADEREWARDCAMPAIGNREQUEST']._serialized_end=11819
  _globals['_QUERYTRADEREWARDCAMPAIGNRESPONSE']._serialized_start=11822
  _globals['_QUERYTRADEREWARDCAMPAIGNRESPONSE']._serialized_end=12460
  _globals['_QUERYISOPTEDOUTOFREWARDSREQUEST']._serialized_start=12462
  _globals['_QUERYISOPTEDOUTOFREWARDSREQUEST']._serialized_end=12521
  _globals['_QUERYISOPTEDOUTOFREWARDSRESPONSE']._serialized_start=12523
  _globals['_QUERYISOPTEDOUTOFREWARDSRESPONSE']._serialized_end=12591
  _globals['_QUERYOPTEDOUTOFREWARDSACCOUNTSREQUEST']._serialized_start=12593
  _globals['_QUERYOPTEDOUTOFREWARDSACCOUNTSREQUEST']._serialized_end=12632
  _globals['_QUERYOPTEDOUTOFREWARDSACCOUNTSRESPONSE']._serialized_start=12634
  _globals['_QUERYOPTEDOUTOFREWARDSACCOUNTSRESPONSE']._serialized_end=12702
  _globals['_QUERYFEEDISCOUNTACCOUNTINFOREQUEST']._serialized_start=12704
  _globals['_QUERYFEEDISCOUNTACCOUNTINFOREQUEST']._serialized_end=12766
  _globals['_QUERYFEEDISCOUNTACCOUNTINFORESPONSE']._serialized_start=12769
  _globals['_QUERYFEEDISCOUNTACCOUNTINFORESPONSE']._serialized_end=13002
  _globals['_QUERYFEEDISCOUNTSCHEDULEREQUEST']._serialized_start=13004
  _globals['_QUERYFEEDISCOUNTSCHEDULEREQUEST']._serialized_end=13037
  _globals['_QUERYFEEDISCOUNTSCHEDULERESPONSE']._serialized_start=13040
  _globals['_QUERYFEEDISCOUNTSCHEDULERESPONSE']._serialized_end=13175
  _globals['_QUERYBALANCEMISMATCHESREQUEST']._serialized_start=13177
  _globals['_QUERYBALANCEMISMATCHESREQUEST']._serialized_end=13241
  _globals['_BALANCEMISMATCH']._serialized_start=13244
  _globals['_BALANCEMISMATCH']._serialized_end=13662
  _globals['_QUERYBALANCEMISMATCHESRESPONSE']._serialized_start=13664
  _globals['_QUERYBALANCEMISMATCHESRESPONSE']._serialized_end=13788
  _globals['_QUERYBALANCEWITHBALANCEHOLDSREQUEST']._serialized_start=13790
  _globals['_QUERYBALANCEWITHBALANCEHOLDSREQUEST']._serialized_end=13827
  _globals['_BALANCEWITHMARGINHOLD']._serialized_start=13830
  _globals['_BALANCEWITHMARGINHOLD']._serialized_end=14109
  _globals['_QUERYBALANCEWITHBALANCEHOLDSRESPONSE']._serialized_start=14112
  _globals['_QUERYBALANCEWITHBALANCEHOLDSRESPONSE']._serialized_end=14262
  _globals['_QUERYFEEDISCOUNTTIERSTATISTICSREQUEST']._serialized_start=14264
  _globals['_QUERYFEEDISCOUNTTIERSTATISTICSREQUEST']._serialized_end=14303
  _globals['_TIERSTATISTIC']._serialized_start=14305
  _globals['_TIERSTATISTIC']._serialized_end=14362
  _globals['_QUERYFEEDISCOUNTTIERSTATISTICSRESPONSE']._serialized_start=14364
  _globals['_QUERYFEEDISCOUNTTIERSTATISTICSRESPONSE']._serialized_end=14479
  _globals['_MITOVAULTINFOSREQUEST']._serialized_start=14481
  _globals['_MITOVAULTINFOSREQUEST']._serialized_end=14504
  _globals['_MITOVAULTINFOSRESPONSE']._serialized_start=14507
  _globals['_MITOVAULTINFOSRESPONSE']._serialized_end=14703
  _globals['_QUERYMARKETIDFROMVAULTREQUEST']._serialized_start=14705
  _globals['_QUERYMARKETIDFROMVAULTREQUEST']._serialized_end=14773
  _globals['_QUERYMARKETIDFROMVAULTRESPONSE']._serialized_start=14775
  _globals['_QUERYMARKETIDFROMVAULTRESPONSE']._serialized_end=14836
  _globals['_QUERYHISTORICALTRADERECORDSREQUEST']._serialized_start=14838
  _globals['_QUERYHISTORICALTRADERECORDSREQUEST']._serialized_end=14903
  _globals['_QUERYHISTORICALTRADERECORDSRESPONSE']._serialized_start=14905
  _globals['_QUERYHISTORICALTRADERECORDSRESPONSE']._serialized_end=15021
  _globals['_TRADEHISTORYOPTIONS']._serialized_start=15024
  _globals['_TRADEHISTORYOPTIONS']._serialized_end=15207
  _globals['_QUERYMARKETVOLATILITYREQUEST']._serialized_start=15210
  _globals['_QUERYMARKETVOLATILITYREQUEST']._serialized_end=15370
  _globals['_QUERYMARKETVOLATILITYRESPONSE']._serialized_start=15373
  _globals['_QUERYMARKETVOLATILITYRESPONSE']._serialized_end=15632
  _globals['_QUERYBINARYMARKETSREQUEST']._serialized_start=15634
  _globals['_QUERYBINARYMARKETSREQUEST']._serialized_end=15685
  _globals['_QUERYBINARYMARKETSRESPONSE']._serialized_start=15687
  _globals['_QUERYBINARYMARKETSRESPONSE']._serialized_end=15790
  _globals['_QUERYTRADERDERIVATIVECONDITIONALORDERSREQUEST']._serialized_start=15792
  _globals['_QUERYTRADERDERIVATIVECONDITIONALORDERSREQUEST']._serialized_end=15905
  _globals['_TRIMMEDDERIVATIVECONDITIONALORDER']._serialized_start=15908
  _globals['_TRIMMEDDERIVATIVECONDITIONALORDER']._serialized_end=16322
  _globals['_QUERYTRADERDERIVATIVECONDITIONALORDERSRESPONSE']._serialized_start=16325
  _globals['_QUERYTRADERDERIVATIVECONDITIONALORDERSRESPONSE']._serialized_end=16460
  _globals['_QUERYFULLSPOTORDERBOOKREQUEST']._serialized_start=16462
  _globals['_QUERYFULLSPOTORDERBOOKREQUEST']._serialized_end=16522
  _globals['_QUERYFULLSPOTORDERBOOKRESPONSE']._serialized_start=16525
  _globals['_QUERYFULLSPOTORDERBOOKRESPONSE']._serialized_end=16691
  _globals['_QUERYFULLDERIVATIVEORDERBOOKREQUEST']._serialized_start=16693
  _globals['_QUERYFULLDERIVATIVEORDERBOOKREQUEST']._serialized_end=16759
  _globals['_QUERYFULLDERIVATIVEORDERBOOKRESPONSE']._serialized_start=16762
  _globals['_QUERYFULLDERIVATIVEORDERBOOKRESPONSE']._serialized_end=16934
  _globals['_TRIMMEDLIMITORDER']._serialized_start=16937
  _globals['_TRIMMEDLIMITORDER']._serialized_end=17148
  _globals['_QUERYMARKETATOMICEXECUTIONFEEMULTIPLIERREQUEST']._serialized_start=17150
  _globals['_QUERYMARKETATOMICEXECUTIONFEEMULTIPLIERREQUEST']._serialized_end=17227
  _globals['_QUERYMARKETATOMICEXECUTIONFEEMULTIPLIERRESPONSE']._serialized_start=17229
  _globals['_QUERYMARKETATOMICEXECUTIONFEEMULTIPLIERRESPONSE']._serialized_end=17347
  _globals['_QUERYACTIVESTAKEGRANTREQUEST']._serialized_start=17349
  _globals['_QUERYACTIVESTAKEGRANTREQUEST']._serialized_end=17405
  _globals['_QUERYACTIVESTAKEGRANTRESPONSE']._serialized_start=17408
  _globals['_QUERYACTIVESTAKEGRANTRESPONSE']._serialized_end=17587
  _globals['_QUERYGRANTAUTHORIZATIONREQUEST']._serialized_start=17589
  _globals['_QUERYGRANTAUTHORIZATIONREQUEST']._serialized_end=17673
  _globals['_QUERYGRANTAUTHORIZATIONRESPONSE']._serialized_start=17675
  _globals['_QUERYGRANTAUTHORIZATIONRESPONSE']._serialized_end=17763
  _globals['_QUERYGRANTAUTHORIZATIONSREQUEST']._serialized_start=17765
  _globals['_QUERYGRANTAUTHORIZATIONSREQUEST']._serialized_end=17824
  _globals['_QUERYGRANTAUTHORIZATIONSRESPONSE']._serialized_start=17827
  _globals['_QUERYGRANTAUTHORIZATIONSRESPONSE']._serialized_end=18010
  _globals['_QUERYMARKETBALANCEREQUEST']._serialized_start=18012
  _globals['_QUERYMARKETBALANCEREQUEST']._serialized_end=18068
  _globals['_QUERYMARKETBALANCERESPONSE']._serialized_start=18070
  _globals['_QUERYMARKETBALANCERESPONSE']._serialized_end=18167
  _globals['_QUERYMARKETBALANCESREQUEST']._serialized_start=18169
  _globals['_QUERYMARKETBALANCESREQUEST']._serialized_end=18197
  _globals['_QUERYMARKETBALANCESRESPONSE']._serialized_start=18199
  _globals['_QUERYMARKETBALANCESRESPONSE']._serialized_end=18299
  _globals['_MARKETBALANCE']._serialized_start=18301
  _globals['_MARKETBALANCE']._serialized_end=18408
  _globals['_QUERYDENOMMINNOTIONALREQUEST']._serialized_start=18410
  _globals['_QUERYDENOMMINNOTIONALREQUEST']._serialized_end=18462
  _globals['_QUERYDENOMMINNOTIONALRESPONSE']._serialized_start=18464
  _globals['_QUERYDENOMMINNOTIONALRESPONSE']._serialized_end=18556
  _globals['_QUERYDENOMMINNOTIONALSREQUEST']._serialized_start=18558
  _globals['_QUERYDENOMMINNOTIONALSREQUEST']._serialized_end=18589
  _globals['_QUERYDENOMMINNOTIONALSRESPONSE']._serialized_start=18591
  _globals['_QUERYDENOMMINNOTIONALSRESPONSE']._serialized_end=18717
  _globals['_QUERY']._serialized_start=18862
  _globals['_QUERY']._serialized_end=33079
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/types/v1beta1/tx_ext.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$injective/types/v1beta1/tx_ext.proto\x12\x17injective.types.v1beta1\x1a\x14gogoproto/gogo.proto\"\x88\x01\n\x16\x45xtensionOptionsWeb3Tx\x12*\n\x10typedDataChainID\x18\x01 \x01(\x04R\x10typedDataChainID\x12\x1a\n\x08\x66\x65\x65Payer\x18\x02 \x01(\tR\x08\x66\x65\x65Payer\x12 \n\x0b\x66\x65\x65PayerSig\x18\x03 \x01(\x0cR\x0b\x66\x65\x65PayerSig:\x04\x88\xa0\x1f\x00\x42\xe6\x01\n\x1b\x63om.injective.types.v1beta1B\nTxExtProtoP\x01Z=github.com/InjectiveLabs/injective-core/injective-chain/types\xa2\x02\x03ITX\xaa\x02\x17Injective.Types.V1beta1\xca\x02\x17Injective\\Types\\V1beta1\xe2\x02#Injective\\Types\\V1beta1\\GPBMetadata\xea\x02\x19Injective::Types::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.types.v1beta1.tx_ext_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.injective.types.v1beta1B\nTxExtProtoP\001Z=github.com/InjectiveLabs/injective-core/injective-chain/types\242\002\003ITX\252\002\027Injective.Types.V1beta1\312\002\027Injective\\Types\\V1beta1\342\002#Injective\\Types\\V1beta1\\GPBMetadata\352\002\031Injective::Types::V1beta1'
  _globals['_EXTENSIONOPTIONSWEB3TX']._loaded_options = None
  _globals['_EXTENSIONOPTIONSWEB3TX']._serialized_options = b'\210\240\037\000'
  _globals['_EXTENSIONOPTIONSWEB3TX']._serialized_start=88
  _globals['_EXTENSIONOPTIONSWEB3TX']._serialized_end=224
# @@protoc_insertion_point(module_scope)
